# coding: utf-8

# flake8: noqa

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from Vpsa.api.consistency_groups_api import ConsistencyGroupsApi
from Vpsa.api.containers_api import ContainersApi
from Vpsa.api.controllers_api import ControllersApi
from Vpsa.api.drives_api import DrivesApi
from Vpsa.api.file_lifecycle_api import FileLifecycleApi
from Vpsa.api.file_lifecycle_policies_api import FileLifecyclePoliciesApi
from Vpsa.api.images_api import ImagesApi
from Vpsa.api.logs_api import LogsApi
from Vpsa.api.mirroring_and_cloning_api import MirroringAndCloningApi
from Vpsa.api.nas_api import NASApi
from Vpsa.api.pools_api import PoolsApi
from Vpsa.api.raid_groups_api import RAIDGroupsApi
from Vpsa.api.remote_object_storage_api import RemoteObjectStorageApi
from Vpsa.api.roles_api import RolesApi
from Vpsa.api.servers_api import ServersApi
from Vpsa.api.settings_api import SettingsApi
from Vpsa.api.snapshot_policies_api import SnapshotPoliciesApi
from Vpsa.api.tickets_api import TicketsApi
from Vpsa.api.users_api import UsersApi
from Vpsa.api.volumes_api import VolumesApi
from Vpsa.api.vpsas_api import VpsasApi

# import ApiClient
from Vpsa.api_client import ApiClient
from Vpsa.configuration import Configuration
# import models into sdk package
from Vpsa.models.add_directories_to_quota_project import AddDirectoriesToQuotaProject
from Vpsa.models.add_hot_spare_to_raid_group import AddHotSpareToRaidGroup
from Vpsa.models.add_mirror_snapshot_policy import AddMirrorSnapshotPolicy
from Vpsa.models.add_role import AddRole
from Vpsa.models.add_secondary_export_name import AddSecondaryExportName
from Vpsa.models.add_user import AddUser
from Vpsa.models.attach_flc_policy import AttachFlcPolicy
from Vpsa.models.attach_servers_to_volume import AttachServersToVolume
from Vpsa.models.attach_snapshot_policy import AttachSnapshotPolicy
from Vpsa.models.attach_snapshot_policy_to_vpsa_mirror_job import AttachSnapshotPolicyToVpsaMirrorJob
from Vpsa.models.backup_jobs_rate_limit import BackupJobsRateLimit
from Vpsa.models.backup_jobs_update_compression import BackupJobsUpdateCompression
from Vpsa.models.break_ros_backup_job import BreakRosBackupJob
from Vpsa.models.break_vpsa_mirror_job import BreakVpsaMirrorJob
from Vpsa.models.cancel_suspend_for_snapshot_set import CancelSuspendForSnapshotSet
from Vpsa.models.change_encryption_to_aws_kms import ChangeEncryptionToAwsKms
from Vpsa.models.change_mtu_for_ni import ChangeMtuForNi
from Vpsa.models.change_nas_user_smb_password import ChangeNasUserSmbPassword
from Vpsa.models.change_ros_restore_job_mode import ChangeRosRestoreJobMode
from Vpsa.models.change_user_pass import ChangeUserPass
from Vpsa.models.change_user_pass_by_temp_code import ChangeUserPassByTempCode
from Vpsa.models.clone_mirror_job import CloneMirrorJob
from Vpsa.models.clone_snapshot_set import CloneSnapshotSet
from Vpsa.models.configure_file_access_audit import ConfigureFileAccessAudit
from Vpsa.models.crate_ticket import CrateTicket
from Vpsa.models.create_category import CreateCategory
from Vpsa.models.create_clone import CreateClone
from Vpsa.models.create_flc_policy import CreateFlcPolicy
from Vpsa.models.create_memory_pool import CreateMemoryPool
from Vpsa.models.create_nas_group import CreateNasGroup
from Vpsa.models.create_nas_user import CreateNasUser
from Vpsa.models.create_pool import CreatePool
from Vpsa.models.create_quota_project import CreateQuotaProject
from Vpsa.models.create_raid_group import CreateRaidGroup
from Vpsa.models.create_remote_clone import CreateRemoteClone
from Vpsa.models.create_ros_backup_job import CreateRosBackupJob
from Vpsa.models.create_ros_destination import CreateRosDestination
from Vpsa.models.create_ros_restore_job import CreateRosRestoreJob
from Vpsa.models.create_server import CreateServer
from Vpsa.models.create_snapshot_policy import CreateSnapshotPolicy
from Vpsa.models.create_snapshot_set_and_resume import CreateSnapshotSetAndResume
from Vpsa.models.create_tag import CreateTag
from Vpsa.models.create_tag1 import CreateTag1
from Vpsa.models.create_ticket_comment import CreateTicketComment
from Vpsa.models.create_volume import CreateVolume
from Vpsa.models.create_volume_mirror import CreateVolumeMirror
from Vpsa.models.create_volume_snapshot import CreateVolumeSnapshot
from Vpsa.models.create_zcs_container import CreateZcsContainer
from Vpsa.models.create_zcs_image import CreateZcsImage
from Vpsa.models.create_zcs_image_repository import CreateZcsImageRepository
from Vpsa.models.default import Default
from Vpsa.models.default_write_policy import DefaultWritePolicy
from Vpsa.models.delete_category import DeleteCategory
from Vpsa.models.delete_clone_snapshot_set import DeleteCloneSnapshotSet
from Vpsa.models.delete_quota_project import DeleteQuotaProject
from Vpsa.models.delete_secondary_export_name import DeleteSecondaryExportName
from Vpsa.models.delete_server_session import DeleteServerSession
from Vpsa.models.delete_snapshot_set import DeleteSnapshotSet
from Vpsa.models.delete_volume import DeleteVolume
from Vpsa.models.detach_flc_policy import DetachFlcPolicy
from Vpsa.models.detach_servers_from_volume import DetachServersFromVolume
from Vpsa.models.detach_snapshot_policy import DetachSnapshotPolicy
from Vpsa.models.detach_snapshot_policy_from_vol import DetachSnapshotPolicyFromVol
from Vpsa.models.disable_file_access_audit_conf import DisableFileAccessAuditConf
from Vpsa.models.disable_privilege_access import DisablePrivilegeAccess
from Vpsa.models.discover_remote_vpsa import DiscoverRemoteVpsa
from Vpsa.models.dump_quotas_file import DumpQuotasFile
from Vpsa.models.dump_quotas_state import DumpQuotasState
from Vpsa.models.edit_active_directory import EditActiveDirectory
from Vpsa.models.error import Error
from Vpsa.models.expand_pool import ExpandPool
from Vpsa.models.expand_volume import ExpandVolume
from Vpsa.models.failover_controller import FailoverController
from Vpsa.models.fetch_volume_quotas import FetchVolumeQuotas
from Vpsa.models.get_all_flc_policies import GetAllFlcPolicies
from Vpsa.models.get_all_flc_policies_rules import GetAllFlcPoliciesRules
from Vpsa.models.get_all_snapshots import GetAllSnapshots
from Vpsa.models.get_user_details import GetUserDetails
from Vpsa.models.get_vols_file_access_auditing_log_time import GetVolsFileAccessAuditingLogTime
from Vpsa.models.get_vols_file_access_auditing_log_time_zip import GetVolsFileAccessAuditingLogTimeZip
from Vpsa.models.get_volume_quota import GetVolumeQuota
from Vpsa.models.inline_response200 import InlineResponse200
from Vpsa.models.inline_response2001 import InlineResponse2001
from Vpsa.models.inline_response20010 import InlineResponse20010
from Vpsa.models.inline_response200100 import InlineResponse200100
from Vpsa.models.inline_response200100_response import InlineResponse200100Response
from Vpsa.models.inline_response200101 import InlineResponse200101
from Vpsa.models.inline_response200101_response import InlineResponse200101Response
from Vpsa.models.inline_response200102 import InlineResponse200102
from Vpsa.models.inline_response200102_response import InlineResponse200102Response
from Vpsa.models.inline_response200103 import InlineResponse200103
from Vpsa.models.inline_response200103_response import InlineResponse200103Response
from Vpsa.models.inline_response200104 import InlineResponse200104
from Vpsa.models.inline_response200104_response import InlineResponse200104Response
from Vpsa.models.inline_response200104_response_remote_vpsas import InlineResponse200104ResponseRemoteVpsas
from Vpsa.models.inline_response200105 import InlineResponse200105
from Vpsa.models.inline_response200105_response import InlineResponse200105Response
from Vpsa.models.inline_response200106 import InlineResponse200106
from Vpsa.models.inline_response200106_response import InlineResponse200106Response
from Vpsa.models.inline_response200106_response_remote_vpsa import InlineResponse200106ResponseRemoteVpsa
from Vpsa.models.inline_response200106_response_remote_vpsa_features import InlineResponse200106ResponseRemoteVpsaFeatures
from Vpsa.models.inline_response200107 import InlineResponse200107
from Vpsa.models.inline_response200107_response import InlineResponse200107Response
from Vpsa.models.inline_response200108 import InlineResponse200108
from Vpsa.models.inline_response200108_response import InlineResponse200108Response
from Vpsa.models.inline_response200109 import InlineResponse200109
from Vpsa.models.inline_response200109_response import InlineResponse200109Response
from Vpsa.models.inline_response200109_response_remote_pools import InlineResponse200109ResponseRemotePools
from Vpsa.models.inline_response20010_response import InlineResponse20010Response
from Vpsa.models.inline_response20011 import InlineResponse20011
from Vpsa.models.inline_response200110 import InlineResponse200110
from Vpsa.models.inline_response200110_response import InlineResponse200110Response
from Vpsa.models.inline_response200110_response_sugested_jobs import InlineResponse200110ResponseSugestedJobs
from Vpsa.models.inline_response200111 import InlineResponse200111
from Vpsa.models.inline_response200111_response import InlineResponse200111Response
from Vpsa.models.inline_response200112 import InlineResponse200112
from Vpsa.models.inline_response200112_response import InlineResponse200112Response
from Vpsa.models.inline_response200113 import InlineResponse200113
from Vpsa.models.inline_response200113_response import InlineResponse200113Response
from Vpsa.models.inline_response200114 import InlineResponse200114
from Vpsa.models.inline_response200114_response import InlineResponse200114Response
from Vpsa.models.inline_response200115 import InlineResponse200115
from Vpsa.models.inline_response200115_response import InlineResponse200115Response
from Vpsa.models.inline_response200116 import InlineResponse200116
from Vpsa.models.inline_response200116_response import InlineResponse200116Response
from Vpsa.models.inline_response200117 import InlineResponse200117
from Vpsa.models.inline_response200117_response import InlineResponse200117Response
from Vpsa.models.inline_response200117_response_snapshots import InlineResponse200117ResponseSnapshots
from Vpsa.models.inline_response200118 import InlineResponse200118
from Vpsa.models.inline_response200118_response import InlineResponse200118Response
from Vpsa.models.inline_response200119 import InlineResponse200119
from Vpsa.models.inline_response200119_response import InlineResponse200119Response
from Vpsa.models.inline_response200119_response_cgs import InlineResponse200119ResponseCgs
from Vpsa.models.inline_response20011_response import InlineResponse20011Response
from Vpsa.models.inline_response20012 import InlineResponse20012
from Vpsa.models.inline_response200120 import InlineResponse200120
from Vpsa.models.inline_response200120_response import InlineResponse200120Response
from Vpsa.models.inline_response200120_response_snapshots import InlineResponse200120ResponseSnapshots
from Vpsa.models.inline_response200121 import InlineResponse200121
from Vpsa.models.inline_response200121_response import InlineResponse200121Response
from Vpsa.models.inline_response200122 import InlineResponse200122
from Vpsa.models.inline_response200122_response import InlineResponse200122Response
from Vpsa.models.inline_response200122_response_dst import InlineResponse200122ResponseDst
from Vpsa.models.inline_response200122_response_remote_clone_jobs import InlineResponse200122ResponseRemoteCloneJobs
from Vpsa.models.inline_response200122_response_src import InlineResponse200122ResponseSrc
from Vpsa.models.inline_response200123 import InlineResponse200123
from Vpsa.models.inline_response200123_response import InlineResponse200123Response
from Vpsa.models.inline_response200123_response_remote_clone_job import InlineResponse200123ResponseRemoteCloneJob
from Vpsa.models.inline_response200123_response_remote_clone_job_dst import InlineResponse200123ResponseRemoteCloneJobDst
from Vpsa.models.inline_response200123_response_remote_clone_job_src import InlineResponse200123ResponseRemoteCloneJobSrc
from Vpsa.models.inline_response200124 import InlineResponse200124
from Vpsa.models.inline_response200124_response import InlineResponse200124Response
from Vpsa.models.inline_response200125 import InlineResponse200125
from Vpsa.models.inline_response200125_response import InlineResponse200125Response
from Vpsa.models.inline_response200126 import InlineResponse200126
from Vpsa.models.inline_response200126_response import InlineResponse200126Response
from Vpsa.models.inline_response200127 import InlineResponse200127
from Vpsa.models.inline_response200127_response import InlineResponse200127Response
from Vpsa.models.inline_response200127_response_obs_destinations import InlineResponse200127ResponseObsDestinations
from Vpsa.models.inline_response200128 import InlineResponse200128
from Vpsa.models.inline_response200128_response import InlineResponse200128Response
from Vpsa.models.inline_response200129 import InlineResponse200129
from Vpsa.models.inline_response200129_response import InlineResponse200129Response
from Vpsa.models.inline_response200129_response_obs_destination import InlineResponse200129ResponseObsDestination
from Vpsa.models.inline_response20012_response import InlineResponse20012Response
from Vpsa.models.inline_response20012_response_usages import InlineResponse20012ResponseUsages
from Vpsa.models.inline_response20013 import InlineResponse20013
from Vpsa.models.inline_response200130 import InlineResponse200130
from Vpsa.models.inline_response200130_response import InlineResponse200130Response
from Vpsa.models.inline_response200131 import InlineResponse200131
from Vpsa.models.inline_response200131_response import InlineResponse200131Response
from Vpsa.models.inline_response200132 import InlineResponse200132
from Vpsa.models.inline_response200132_response import InlineResponse200132Response
from Vpsa.models.inline_response200132_response_dst import InlineResponse200132ResponseDst
from Vpsa.models.inline_response200132_response_obs_backup_jobs import InlineResponse200132ResponseObsBackupJobs
from Vpsa.models.inline_response200132_response_snapshot_policy import InlineResponse200132ResponseSnapshotPolicy
from Vpsa.models.inline_response200132_response_src import InlineResponse200132ResponseSrc
from Vpsa.models.inline_response200133 import InlineResponse200133
from Vpsa.models.inline_response200133_response import InlineResponse200133Response
from Vpsa.models.inline_response200133_response_dst import InlineResponse200133ResponseDst
from Vpsa.models.inline_response200133_response_obs_restore_jobs import InlineResponse200133ResponseObsRestoreJobs
from Vpsa.models.inline_response200133_response_src import InlineResponse200133ResponseSrc
from Vpsa.models.inline_response200134 import InlineResponse200134
from Vpsa.models.inline_response200134_response import InlineResponse200134Response
from Vpsa.models.inline_response200134_response_dst import InlineResponse200134ResponseDst
from Vpsa.models.inline_response200134_response_obs_backup_jobs import InlineResponse200134ResponseObsBackupJobs
from Vpsa.models.inline_response200135 import InlineResponse200135
from Vpsa.models.inline_response200135_response import InlineResponse200135Response
from Vpsa.models.inline_response200136 import InlineResponse200136
from Vpsa.models.inline_response200136_response import InlineResponse200136Response
from Vpsa.models.inline_response200136_response_obs_backup_job import InlineResponse200136ResponseObsBackupJob
from Vpsa.models.inline_response200136_response_obs_backup_job_snapshot_policy import InlineResponse200136ResponseObsBackupJobSnapshotPolicy
from Vpsa.models.inline_response200136_response_obs_backup_job_src import InlineResponse200136ResponseObsBackupJobSrc
from Vpsa.models.inline_response200137 import InlineResponse200137
from Vpsa.models.inline_response200137_response import InlineResponse200137Response
from Vpsa.models.inline_response200138 import InlineResponse200138
from Vpsa.models.inline_response200138_response import InlineResponse200138Response
from Vpsa.models.inline_response200139 import InlineResponse200139
from Vpsa.models.inline_response200139_response import InlineResponse200139Response
from Vpsa.models.inline_response20013_response import InlineResponse20013Response
from Vpsa.models.inline_response20013_response_container_memory_pools import InlineResponse20013ResponseContainerMemoryPools
from Vpsa.models.inline_response20013_response_containers import InlineResponse20013ResponseContainers
from Vpsa.models.inline_response20014 import InlineResponse20014
from Vpsa.models.inline_response200140 import InlineResponse200140
from Vpsa.models.inline_response200140_response import InlineResponse200140Response
from Vpsa.models.inline_response200141 import InlineResponse200141
from Vpsa.models.inline_response200141_response import InlineResponse200141Response
from Vpsa.models.inline_response200142 import InlineResponse200142
from Vpsa.models.inline_response200142_response import InlineResponse200142Response
from Vpsa.models.inline_response200143 import InlineResponse200143
from Vpsa.models.inline_response200143_response import InlineResponse200143Response
from Vpsa.models.inline_response200144 import InlineResponse200144
from Vpsa.models.inline_response200144_response import InlineResponse200144Response
from Vpsa.models.inline_response200144_response_usages import InlineResponse200144ResponseUsages
from Vpsa.models.inline_response200145 import InlineResponse200145
from Vpsa.models.inline_response200145_response import InlineResponse200145Response
from Vpsa.models.inline_response200145_response_dst import InlineResponse200145ResponseDst
from Vpsa.models.inline_response200145_response_obs_restore_jobs import InlineResponse200145ResponseObsRestoreJobs
from Vpsa.models.inline_response200145_response_src import InlineResponse200145ResponseSrc
from Vpsa.models.inline_response200146 import InlineResponse200146
from Vpsa.models.inline_response200146_response import InlineResponse200146Response
from Vpsa.models.inline_response200147 import InlineResponse200147
from Vpsa.models.inline_response200147_response import InlineResponse200147Response
from Vpsa.models.inline_response200147_response_obs_restore_job import InlineResponse200147ResponseObsRestoreJob
from Vpsa.models.inline_response200147_response_obs_restore_job_dst import InlineResponse200147ResponseObsRestoreJobDst
from Vpsa.models.inline_response200148 import InlineResponse200148
from Vpsa.models.inline_response200148_response import InlineResponse200148Response
from Vpsa.models.inline_response200149 import InlineResponse200149
from Vpsa.models.inline_response200149_response import InlineResponse200149Response
from Vpsa.models.inline_response20014_response import InlineResponse20014Response
from Vpsa.models.inline_response20015 import InlineResponse20015
from Vpsa.models.inline_response200150 import InlineResponse200150
from Vpsa.models.inline_response200150_response import InlineResponse200150Response
from Vpsa.models.inline_response200151 import InlineResponse200151
from Vpsa.models.inline_response200151_response import InlineResponse200151Response
from Vpsa.models.inline_response200152 import InlineResponse200152
from Vpsa.models.inline_response200152_response import InlineResponse200152Response
from Vpsa.models.inline_response200152_response_usages import InlineResponse200152ResponseUsages
from Vpsa.models.inline_response200153 import InlineResponse200153
from Vpsa.models.inline_response200153_response import InlineResponse200153Response
from Vpsa.models.inline_response200153_response_permissions import InlineResponse200153ResponsePermissions
from Vpsa.models.inline_response200153_response_roles import InlineResponse200153ResponseRoles
from Vpsa.models.inline_response200154 import InlineResponse200154
from Vpsa.models.inline_response200154_response import InlineResponse200154Response
from Vpsa.models.inline_response200155 import InlineResponse200155
from Vpsa.models.inline_response200155_response import InlineResponse200155Response
from Vpsa.models.inline_response200155_response_permissions import InlineResponse200155ResponsePermissions
from Vpsa.models.inline_response200156 import InlineResponse200156
from Vpsa.models.inline_response200156_response import InlineResponse200156Response
from Vpsa.models.inline_response200157 import InlineResponse200157
from Vpsa.models.inline_response200157_response import InlineResponse200157Response
from Vpsa.models.inline_response200158 import InlineResponse200158
from Vpsa.models.inline_response200158_response import InlineResponse200158Response
from Vpsa.models.inline_response200158_response_servers import InlineResponse200158ResponseServers
from Vpsa.models.inline_response200159 import InlineResponse200159
from Vpsa.models.inline_response200159_response import InlineResponse200159Response
from Vpsa.models.inline_response20015_response import InlineResponse20015Response
from Vpsa.models.inline_response20015_response_container_memory_pool import InlineResponse20015ResponseContainerMemoryPool
from Vpsa.models.inline_response20016 import InlineResponse20016
from Vpsa.models.inline_response200160 import InlineResponse200160
from Vpsa.models.inline_response200160_response import InlineResponse200160Response
from Vpsa.models.inline_response200160_response_server import InlineResponse200160ResponseServer
from Vpsa.models.inline_response200161 import InlineResponse200161
from Vpsa.models.inline_response200161_response import InlineResponse200161Response
from Vpsa.models.inline_response200162 import InlineResponse200162
from Vpsa.models.inline_response200162_response import InlineResponse200162Response
from Vpsa.models.inline_response200162_response_sessions import InlineResponse200162ResponseSessions
from Vpsa.models.inline_response200163 import InlineResponse200163
from Vpsa.models.inline_response200163_response import InlineResponse200163Response
from Vpsa.models.inline_response200164 import InlineResponse200164
from Vpsa.models.inline_response200164_response import InlineResponse200164Response
from Vpsa.models.inline_response200165 import InlineResponse200165
from Vpsa.models.inline_response200165_response import InlineResponse200165Response
from Vpsa.models.inline_response200166 import InlineResponse200166
from Vpsa.models.inline_response200166_response import InlineResponse200166Response
from Vpsa.models.inline_response200166_response_volumes import InlineResponse200166ResponseVolumes
from Vpsa.models.inline_response200167 import InlineResponse200167
from Vpsa.models.inline_response200167_response import InlineResponse200167Response
from Vpsa.models.inline_response200168 import InlineResponse200168
from Vpsa.models.inline_response200168_response import InlineResponse200168Response
from Vpsa.models.inline_response200169 import InlineResponse200169
from Vpsa.models.inline_response200169_response import InlineResponse200169Response
from Vpsa.models.inline_response20016_response import InlineResponse20016Response
from Vpsa.models.inline_response20017 import InlineResponse20017
from Vpsa.models.inline_response200170 import InlineResponse200170
from Vpsa.models.inline_response200170_response import InlineResponse200170Response
from Vpsa.models.inline_response200171 import InlineResponse200171
from Vpsa.models.inline_response200171_response import InlineResponse200171Response
from Vpsa.models.inline_response200172 import InlineResponse200172
from Vpsa.models.inline_response200172_response import InlineResponse200172Response
from Vpsa.models.inline_response200173 import InlineResponse200173
from Vpsa.models.inline_response200173_response import InlineResponse200173Response
from Vpsa.models.inline_response200174 import InlineResponse200174
from Vpsa.models.inline_response200174_response import InlineResponse200174Response
from Vpsa.models.inline_response200175 import InlineResponse200175
from Vpsa.models.inline_response200175_response import InlineResponse200175Response
from Vpsa.models.inline_response200176 import InlineResponse200176
from Vpsa.models.inline_response200176_response import InlineResponse200176Response
from Vpsa.models.inline_response200177 import InlineResponse200177
from Vpsa.models.inline_response200177_response import InlineResponse200177Response
from Vpsa.models.inline_response200178 import InlineResponse200178
from Vpsa.models.inline_response200178_response import InlineResponse200178Response
from Vpsa.models.inline_response200179 import InlineResponse200179
from Vpsa.models.inline_response200179_response import InlineResponse200179Response
from Vpsa.models.inline_response20017_response import InlineResponse20017Response
from Vpsa.models.inline_response20017_response_vcontrollers import InlineResponse20017ResponseVcontrollers
from Vpsa.models.inline_response20018 import InlineResponse20018
from Vpsa.models.inline_response200180 import InlineResponse200180
from Vpsa.models.inline_response200180_response import InlineResponse200180Response
from Vpsa.models.inline_response200181 import InlineResponse200181
from Vpsa.models.inline_response200181_response import InlineResponse200181Response
from Vpsa.models.inline_response200182 import InlineResponse200182
from Vpsa.models.inline_response200182_response import InlineResponse200182Response
from Vpsa.models.inline_response200183 import InlineResponse200183
from Vpsa.models.inline_response200183_response import InlineResponse200183Response
from Vpsa.models.inline_response200184 import InlineResponse200184
from Vpsa.models.inline_response200184_response import InlineResponse200184Response
from Vpsa.models.inline_response200185 import InlineResponse200185
from Vpsa.models.inline_response200185_response import InlineResponse200185Response
from Vpsa.models.inline_response200185_response_audit_configuration import InlineResponse200185ResponseAuditConfiguration
from Vpsa.models.inline_response200186 import InlineResponse200186
from Vpsa.models.inline_response200186_response import InlineResponse200186Response
from Vpsa.models.inline_response200187 import InlineResponse200187
from Vpsa.models.inline_response200187_response import InlineResponse200187Response
from Vpsa.models.inline_response200187_response_container_service_settings import InlineResponse200187ResponseContainerServiceSettings
from Vpsa.models.inline_response200187_response_container_service_settings_images_repository import InlineResponse200187ResponseContainerServiceSettingsImagesRepository
from Vpsa.models.inline_response200187_response_container_service_settings_ports import InlineResponse200187ResponseContainerServiceSettingsPorts
from Vpsa.models.inline_response200188 import InlineResponse200188
from Vpsa.models.inline_response200188_response import InlineResponse200188Response
from Vpsa.models.inline_response200189 import InlineResponse200189
from Vpsa.models.inline_response200189_response import InlineResponse200189Response
from Vpsa.models.inline_response20018_response import InlineResponse20018Response
from Vpsa.models.inline_response20018_response_vnis import InlineResponse20018ResponseVnis
from Vpsa.models.inline_response20019 import InlineResponse20019
from Vpsa.models.inline_response200190 import InlineResponse200190
from Vpsa.models.inline_response200190_response import InlineResponse200190Response
from Vpsa.models.inline_response200191 import InlineResponse200191
from Vpsa.models.inline_response200191_response import InlineResponse200191Response
from Vpsa.models.inline_response200192 import InlineResponse200192
from Vpsa.models.inline_response200192_hash import InlineResponse200192Hash
from Vpsa.models.inline_response200193 import InlineResponse200193
from Vpsa.models.inline_response200193_response import InlineResponse200193Response
from Vpsa.models.inline_response200194 import InlineResponse200194
from Vpsa.models.inline_response200194_response import InlineResponse200194Response
from Vpsa.models.inline_response200195 import InlineResponse200195
from Vpsa.models.inline_response200195_response import InlineResponse200195Response
from Vpsa.models.inline_response200196 import InlineResponse200196
from Vpsa.models.inline_response200197 import InlineResponse200197
from Vpsa.models.inline_response200197_response import InlineResponse200197Response
from Vpsa.models.inline_response200197_response_snapshot_policies import InlineResponse200197ResponseSnapshotPolicies
from Vpsa.models.inline_response200198 import InlineResponse200198
from Vpsa.models.inline_response200198_response import InlineResponse200198Response
from Vpsa.models.inline_response200199 import InlineResponse200199
from Vpsa.models.inline_response200199_response import InlineResponse200199Response
from Vpsa.models.inline_response200199_response_snapshot_policy import InlineResponse200199ResponseSnapshotPolicy
from Vpsa.models.inline_response20019_response import InlineResponse20019Response
from Vpsa.models.inline_response2001_response import InlineResponse2001Response
from Vpsa.models.inline_response2002 import InlineResponse2002
from Vpsa.models.inline_response20020 import InlineResponse20020
from Vpsa.models.inline_response200200 import InlineResponse200200
from Vpsa.models.inline_response200200_response import InlineResponse200200Response
from Vpsa.models.inline_response200201 import InlineResponse200201
from Vpsa.models.inline_response200201_response import InlineResponse200201Response
from Vpsa.models.inline_response200202 import InlineResponse200202
from Vpsa.models.inline_response200202_response import InlineResponse200202Response
from Vpsa.models.inline_response200203 import InlineResponse200203
from Vpsa.models.inline_response200203_response import InlineResponse200203Response
from Vpsa.models.inline_response200203_response_volumes import InlineResponse200203ResponseVolumes
from Vpsa.models.inline_response200204 import InlineResponse200204
from Vpsa.models.inline_response200204_response import InlineResponse200204Response
from Vpsa.models.inline_response200204_response_tickets import InlineResponse200204ResponseTickets
from Vpsa.models.inline_response200205 import InlineResponse200205
from Vpsa.models.inline_response200205_response import InlineResponse200205Response
from Vpsa.models.inline_response200206 import InlineResponse200206
from Vpsa.models.inline_response200206_response import InlineResponse200206Response
from Vpsa.models.inline_response200207 import InlineResponse200207
from Vpsa.models.inline_response200207_response import InlineResponse200207Response
from Vpsa.models.inline_response200207_response_comments import InlineResponse200207ResponseComments
from Vpsa.models.inline_response200208 import InlineResponse200208
from Vpsa.models.inline_response200208_response import InlineResponse200208Response
from Vpsa.models.inline_response200209 import InlineResponse200209
from Vpsa.models.inline_response200209_response import InlineResponse200209Response
from Vpsa.models.inline_response20020_response import InlineResponse20020Response
from Vpsa.models.inline_response20020_response_sessions import InlineResponse20020ResponseSessions
from Vpsa.models.inline_response20021 import InlineResponse20021
from Vpsa.models.inline_response200210 import InlineResponse200210
from Vpsa.models.inline_response200210_response import InlineResponse200210Response
from Vpsa.models.inline_response200210_response_roles import InlineResponse200210ResponseRoles
from Vpsa.models.inline_response200210_response_users import InlineResponse200210ResponseUsers
from Vpsa.models.inline_response200211 import InlineResponse200211
from Vpsa.models.inline_response200211_response import InlineResponse200211Response
from Vpsa.models.inline_response200212 import InlineResponse200212
from Vpsa.models.inline_response200212_response import InlineResponse200212Response
from Vpsa.models.inline_response200213 import InlineResponse200213
from Vpsa.models.inline_response200213_response import InlineResponse200213Response
from Vpsa.models.inline_response200214 import InlineResponse200214
from Vpsa.models.inline_response200214_response import InlineResponse200214Response
from Vpsa.models.inline_response200215 import InlineResponse200215
from Vpsa.models.inline_response200215_user import InlineResponse200215User
from Vpsa.models.inline_response200216 import InlineResponse200216
from Vpsa.models.inline_response200216_response import InlineResponse200216Response
from Vpsa.models.inline_response200217 import InlineResponse200217
from Vpsa.models.inline_response200217_response import InlineResponse200217Response
from Vpsa.models.inline_response200218 import InlineResponse200218
from Vpsa.models.inline_response200219 import InlineResponse200219
from Vpsa.models.inline_response200219_response import InlineResponse200219Response
from Vpsa.models.inline_response20021_response import InlineResponse20021Response
from Vpsa.models.inline_response20021_response_usages import InlineResponse20021ResponseUsages
from Vpsa.models.inline_response20022 import InlineResponse20022
from Vpsa.models.inline_response200220 import InlineResponse200220
from Vpsa.models.inline_response200220_response import InlineResponse200220Response
from Vpsa.models.inline_response200221 import InlineResponse200221
from Vpsa.models.inline_response200221_response import InlineResponse200221Response
from Vpsa.models.inline_response200222 import InlineResponse200222
from Vpsa.models.inline_response200222_response import InlineResponse200222Response
from Vpsa.models.inline_response200222_response_password_requirements_data import InlineResponse200222ResponsePasswordRequirementsData
from Vpsa.models.inline_response200223 import InlineResponse200223
from Vpsa.models.inline_response200223_response import InlineResponse200223Response
from Vpsa.models.inline_response200223_response_volumes import InlineResponse200223ResponseVolumes
from Vpsa.models.inline_response200224 import InlineResponse200224
from Vpsa.models.inline_response200224_response import InlineResponse200224Response
from Vpsa.models.inline_response200224_response_volume import InlineResponse200224ResponseVolume
from Vpsa.models.inline_response200225 import InlineResponse200225
from Vpsa.models.inline_response200225_response import InlineResponse200225Response
from Vpsa.models.inline_response200226 import InlineResponse200226
from Vpsa.models.inline_response200226_response import InlineResponse200226Response
from Vpsa.models.inline_response200227 import InlineResponse200227
from Vpsa.models.inline_response200227_response import InlineResponse200227Response
from Vpsa.models.inline_response200227_response_volumes import InlineResponse200227ResponseVolumes
from Vpsa.models.inline_response200228 import InlineResponse200228
from Vpsa.models.inline_response200228_response import InlineResponse200228Response
from Vpsa.models.inline_response200229 import InlineResponse200229
from Vpsa.models.inline_response200229_response import InlineResponse200229Response
from Vpsa.models.inline_response20022_response import InlineResponse20022Response
from Vpsa.models.inline_response20022_response_zcache_usages import InlineResponse20022ResponseZcacheUsages
from Vpsa.models.inline_response20023 import InlineResponse20023
from Vpsa.models.inline_response200230 import InlineResponse200230
from Vpsa.models.inline_response200230_response import InlineResponse200230Response
from Vpsa.models.inline_response200230_response_servers import InlineResponse200230ResponseServers
from Vpsa.models.inline_response200231 import InlineResponse200231
from Vpsa.models.inline_response200231_response import InlineResponse200231Response
from Vpsa.models.inline_response200232 import InlineResponse200232
from Vpsa.models.inline_response200232_response import InlineResponse200232Response
from Vpsa.models.inline_response200233 import InlineResponse200233
from Vpsa.models.inline_response200233_response import InlineResponse200233Response
from Vpsa.models.inline_response200234 import InlineResponse200234
from Vpsa.models.inline_response200234_delete_volume_from_recycle_bin import InlineResponse200234DeleteVolumeFromRecycleBin
from Vpsa.models.inline_response200235 import InlineResponse200235
from Vpsa.models.inline_response200235_response import InlineResponse200235Response
from Vpsa.models.inline_response200235_response_snapshot_policies import InlineResponse200235ResponseSnapshotPolicies
from Vpsa.models.inline_response200236 import InlineResponse200236
from Vpsa.models.inline_response200236_response import InlineResponse200236Response
from Vpsa.models.inline_response200236_response_file_histories import InlineResponse200236ResponseFileHistories
from Vpsa.models.inline_response200237 import InlineResponse200237
from Vpsa.models.inline_response200237_response import InlineResponse200237Response
from Vpsa.models.inline_response200238 import InlineResponse200238
from Vpsa.models.inline_response200238_response import InlineResponse200238Response
from Vpsa.models.inline_response200239 import InlineResponse200239
from Vpsa.models.inline_response200239_response import InlineResponse200239Response
from Vpsa.models.inline_response20023_response import InlineResponse20023Response
from Vpsa.models.inline_response20023_response_usages import InlineResponse20023ResponseUsages
from Vpsa.models.inline_response20024 import InlineResponse20024
from Vpsa.models.inline_response200240 import InlineResponse200240
from Vpsa.models.inline_response200240_response import InlineResponse200240Response
from Vpsa.models.inline_response200240_response_snapshots import InlineResponse200240ResponseSnapshots
from Vpsa.models.inline_response200241 import InlineResponse200241
from Vpsa.models.inline_response200241_response import InlineResponse200241Response
from Vpsa.models.inline_response200242 import InlineResponse200242
from Vpsa.models.inline_response200242_response import InlineResponse200242Response
from Vpsa.models.inline_response200242_response_snapshot import InlineResponse200242ResponseSnapshot
from Vpsa.models.inline_response200243 import InlineResponse200243
from Vpsa.models.inline_response200243_response import InlineResponse200243Response
from Vpsa.models.inline_response200244 import InlineResponse200244
from Vpsa.models.inline_response200244_response import InlineResponse200244Response
from Vpsa.models.inline_response200245 import InlineResponse200245
from Vpsa.models.inline_response200245_response import InlineResponse200245Response
from Vpsa.models.inline_response200245_response_migration_job import InlineResponse200245ResponseMigrationJob
from Vpsa.models.inline_response200246 import InlineResponse200246
from Vpsa.models.inline_response200246_response import InlineResponse200246Response
from Vpsa.models.inline_response200247 import InlineResponse200247
from Vpsa.models.inline_response200247_response import InlineResponse200247Response
from Vpsa.models.inline_response200248 import InlineResponse200248
from Vpsa.models.inline_response200248_response import InlineResponse200248Response
from Vpsa.models.inline_response200249 import InlineResponse200249
from Vpsa.models.inline_response200249_response import InlineResponse200249Response
from Vpsa.models.inline_response20024_response import InlineResponse20024Response
from Vpsa.models.inline_response20024_response_disks import InlineResponse20024ResponseDisks
from Vpsa.models.inline_response20025 import InlineResponse20025
from Vpsa.models.inline_response200250 import InlineResponse200250
from Vpsa.models.inline_response200250_response import InlineResponse200250Response
from Vpsa.models.inline_response200251 import InlineResponse200251
from Vpsa.models.inline_response200251_response import InlineResponse200251Response
from Vpsa.models.inline_response200252 import InlineResponse200252
from Vpsa.models.inline_response200252_response import InlineResponse200252Response
from Vpsa.models.inline_response200252_response_quotas import InlineResponse200252ResponseQuotas
from Vpsa.models.inline_response200253 import InlineResponse200253
from Vpsa.models.inline_response200253_response import InlineResponse200253Response
from Vpsa.models.inline_response200254 import InlineResponse200254
from Vpsa.models.inline_response200254_response import InlineResponse200254Response
from Vpsa.models.inline_response200255 import InlineResponse200255
from Vpsa.models.inline_response200255_response import InlineResponse200255Response
from Vpsa.models.inline_response200256 import InlineResponse200256
from Vpsa.models.inline_response200256_response import InlineResponse200256Response
from Vpsa.models.inline_response200257 import InlineResponse200257
from Vpsa.models.inline_response200257_response import InlineResponse200257Response
from Vpsa.models.inline_response200258 import InlineResponse200258
from Vpsa.models.inline_response200258_response import InlineResponse200258Response
from Vpsa.models.inline_response200258_response_directories import InlineResponse200258ResponseDirectories
from Vpsa.models.inline_response200258_response_projects import InlineResponse200258ResponseProjects
from Vpsa.models.inline_response200259 import InlineResponse200259
from Vpsa.models.inline_response200259_response import InlineResponse200259Response
from Vpsa.models.inline_response20025_response import InlineResponse20025Response
from Vpsa.models.inline_response20025_response_disk import InlineResponse20025ResponseDisk
from Vpsa.models.inline_response20026 import InlineResponse20026
from Vpsa.models.inline_response200260 import InlineResponse200260
from Vpsa.models.inline_response200260_response import InlineResponse200260Response
from Vpsa.models.inline_response200261 import InlineResponse200261
from Vpsa.models.inline_response200261_response import InlineResponse200261Response
from Vpsa.models.inline_response200262 import InlineResponse200262
from Vpsa.models.inline_response200262_response import InlineResponse200262Response
from Vpsa.models.inline_response200263 import InlineResponse200263
from Vpsa.models.inline_response200263_response import InlineResponse200263Response
from Vpsa.models.inline_response200264 import InlineResponse200264
from Vpsa.models.inline_response200264_response import InlineResponse200264Response
from Vpsa.models.inline_response200265 import InlineResponse200265
from Vpsa.models.inline_response200265_response import InlineResponse200265Response
from Vpsa.models.inline_response200265_response_tags import InlineResponse200265ResponseTags
from Vpsa.models.inline_response200266 import InlineResponse200266
from Vpsa.models.inline_response200266_response import InlineResponse200266Response
from Vpsa.models.inline_response200267 import InlineResponse200267
from Vpsa.models.inline_response200267_response import InlineResponse200267Response
from Vpsa.models.inline_response200268 import InlineResponse200268
from Vpsa.models.inline_response200268_response import InlineResponse200268Response
from Vpsa.models.inline_response200269 import InlineResponse200269
from Vpsa.models.inline_response200269_response import InlineResponse200269Response
from Vpsa.models.inline_response200269_response_vsa import InlineResponse200269ResponseVsa
from Vpsa.models.inline_response20026_response import InlineResponse20026Response
from Vpsa.models.inline_response20026_response_disks import InlineResponse20026ResponseDisks
from Vpsa.models.inline_response20027 import InlineResponse20027
from Vpsa.models.inline_response20027_response import InlineResponse20027Response
from Vpsa.models.inline_response20028 import InlineResponse20028
from Vpsa.models.inline_response20028_response import InlineResponse20028Response
from Vpsa.models.inline_response20029 import InlineResponse20029
from Vpsa.models.inline_response20029_response import InlineResponse20029Response
from Vpsa.models.inline_response2002_response import InlineResponse2002Response
from Vpsa.models.inline_response2003 import InlineResponse2003
from Vpsa.models.inline_response20030 import InlineResponse20030
from Vpsa.models.inline_response20030_response import InlineResponse20030Response
from Vpsa.models.inline_response20031 import InlineResponse20031
from Vpsa.models.inline_response20031_response import InlineResponse20031Response
from Vpsa.models.inline_response20032 import InlineResponse20032
from Vpsa.models.inline_response20032_response import InlineResponse20032Response
from Vpsa.models.inline_response20032_response_usages import InlineResponse20032ResponseUsages
from Vpsa.models.inline_response20033 import InlineResponse20033
from Vpsa.models.inline_response20033_response import InlineResponse20033Response
from Vpsa.models.inline_response20033_response_lc_policies import InlineResponse20033ResponseLcPolicies
from Vpsa.models.inline_response20034 import InlineResponse20034
from Vpsa.models.inline_response20034_response import InlineResponse20034Response
from Vpsa.models.inline_response20035 import InlineResponse20035
from Vpsa.models.inline_response20036 import InlineResponse20036
from Vpsa.models.inline_response20036_response import InlineResponse20036Response
from Vpsa.models.inline_response20036_response_life_cycle_policy import InlineResponse20036ResponseLifeCyclePolicy
from Vpsa.models.inline_response20037 import InlineResponse20037
from Vpsa.models.inline_response20037_response import InlineResponse20037Response
from Vpsa.models.inline_response20038 import InlineResponse20038
from Vpsa.models.inline_response20038_response import InlineResponse20038Response
from Vpsa.models.inline_response20039 import InlineResponse20039
from Vpsa.models.inline_response20039_response import InlineResponse20039Response
from Vpsa.models.inline_response2003_response import InlineResponse2003Response
from Vpsa.models.inline_response2004 import InlineResponse2004
from Vpsa.models.inline_response20040 import InlineResponse20040
from Vpsa.models.inline_response20040_response import InlineResponse20040Response
from Vpsa.models.inline_response20040_response_categories import InlineResponse20040ResponseCategories
from Vpsa.models.inline_response20041 import InlineResponse20041
from Vpsa.models.inline_response20041_response import InlineResponse20041Response
from Vpsa.models.inline_response20042 import InlineResponse20042
from Vpsa.models.inline_response20042_response import InlineResponse20042Response
from Vpsa.models.inline_response20043 import InlineResponse20043
from Vpsa.models.inline_response20043_response import InlineResponse20043Response
from Vpsa.models.inline_response20044 import InlineResponse20044
from Vpsa.models.inline_response20044_response import InlineResponse20044Response
from Vpsa.models.inline_response20045 import InlineResponse20045
from Vpsa.models.inline_response20045_response import InlineResponse20045Response
from Vpsa.models.inline_response20045_response_documents_spreadsheets_and_text_files import InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles
from Vpsa.models.inline_response20045_response_resources import InlineResponse20045ResponseResources
from Vpsa.models.inline_response20045_response_uncategorized import InlineResponse20045ResponseUncategorized
from Vpsa.models.inline_response20045_response_usages import InlineResponse20045ResponseUsages
from Vpsa.models.inline_response20046 import InlineResponse20046
from Vpsa.models.inline_response20046_response import InlineResponse20046Response
from Vpsa.models.inline_response20046_response_images import InlineResponse20046ResponseImages
from Vpsa.models.inline_response20047 import InlineResponse20047
from Vpsa.models.inline_response20047_response import InlineResponse20047Response
from Vpsa.models.inline_response20048 import InlineResponse20048
from Vpsa.models.inline_response20048_response import InlineResponse20048Response
from Vpsa.models.inline_response20048_response_image import InlineResponse20048ResponseImage
from Vpsa.models.inline_response20049 import InlineResponse20049
from Vpsa.models.inline_response20049_response import InlineResponse20049Response
from Vpsa.models.inline_response2004_response import InlineResponse2004Response
from Vpsa.models.inline_response2005 import InlineResponse2005
from Vpsa.models.inline_response20050 import InlineResponse20050
from Vpsa.models.inline_response20050_response import InlineResponse20050Response
from Vpsa.models.inline_response20051 import InlineResponse20051
from Vpsa.models.inline_response20051_response import InlineResponse20051Response
from Vpsa.models.inline_response20051_response_messages import InlineResponse20051ResponseMessages
from Vpsa.models.inline_response20052 import InlineResponse20052
from Vpsa.models.inline_response20052_response import InlineResponse20052Response
from Vpsa.models.inline_response20052_response_users import InlineResponse20052ResponseUsers
from Vpsa.models.inline_response20053 import InlineResponse20053
from Vpsa.models.inline_response20053_response import InlineResponse20053Response
from Vpsa.models.inline_response20054 import InlineResponse20054
from Vpsa.models.inline_response20054_response import InlineResponse20054Response
from Vpsa.models.inline_response20054_response_user import InlineResponse20054ResponseUser
from Vpsa.models.inline_response20055 import InlineResponse20055
from Vpsa.models.inline_response20055_response import InlineResponse20055Response
from Vpsa.models.inline_response20056 import InlineResponse20056
from Vpsa.models.inline_response20056_response import InlineResponse20056Response
from Vpsa.models.inline_response20057 import InlineResponse20057
from Vpsa.models.inline_response20057_response import InlineResponse20057Response
from Vpsa.models.inline_response20057_response_groups import InlineResponse20057ResponseGroups
from Vpsa.models.inline_response20058 import InlineResponse20058
from Vpsa.models.inline_response20058_response import InlineResponse20058Response
from Vpsa.models.inline_response20059 import InlineResponse20059
from Vpsa.models.inline_response20059_response import InlineResponse20059Response
from Vpsa.models.inline_response20059_response_group import InlineResponse20059ResponseGroup
from Vpsa.models.inline_response2005_response import InlineResponse2005Response
from Vpsa.models.inline_response2006 import InlineResponse2006
from Vpsa.models.inline_response20060 import InlineResponse20060
from Vpsa.models.inline_response20060_response import InlineResponse20060Response
from Vpsa.models.inline_response20061 import InlineResponse20061
from Vpsa.models.inline_response20061_response import InlineResponse20061Response
from Vpsa.models.inline_response20061_response_smb_ads import InlineResponse20061ResponseSmbAds
from Vpsa.models.inline_response20062 import InlineResponse20062
from Vpsa.models.inline_response20062_response import InlineResponse20062Response
from Vpsa.models.inline_response20063 import InlineResponse20063
from Vpsa.models.inline_response20063_response import InlineResponse20063Response
from Vpsa.models.inline_response20064 import InlineResponse20064
from Vpsa.models.inline_response20064_response import InlineResponse20064Response
from Vpsa.models.inline_response20065 import InlineResponse20065
from Vpsa.models.inline_response20065_response import InlineResponse20065Response
from Vpsa.models.inline_response20066 import InlineResponse20066
from Vpsa.models.inline_response20066_response import InlineResponse20066Response
from Vpsa.models.inline_response20066_response_pools import InlineResponse20066ResponsePools
from Vpsa.models.inline_response20067 import InlineResponse20067
from Vpsa.models.inline_response20067_response import InlineResponse20067Response
from Vpsa.models.inline_response20068 import InlineResponse20068
from Vpsa.models.inline_response20068_response import InlineResponse20068Response
from Vpsa.models.inline_response20068_response_pool import InlineResponse20068ResponsePool
from Vpsa.models.inline_response20068_response_pool_ssd import InlineResponse20068ResponsePoolSsd
from Vpsa.models.inline_response20069 import InlineResponse20069
from Vpsa.models.inline_response20069_response import InlineResponse20069Response
from Vpsa.models.inline_response2006_response import InlineResponse2006Response
from Vpsa.models.inline_response2006_response_containers import InlineResponse2006ResponseContainers
from Vpsa.models.inline_response2006_response_volumes import InlineResponse2006ResponseVolumes
from Vpsa.models.inline_response2007 import InlineResponse2007
from Vpsa.models.inline_response20070 import InlineResponse20070
from Vpsa.models.inline_response20070_response import InlineResponse20070Response
from Vpsa.models.inline_response20071 import InlineResponse20071
from Vpsa.models.inline_response20071_response import InlineResponse20071Response
from Vpsa.models.inline_response20071_response_raid_groups import InlineResponse20071ResponseRaidGroups
from Vpsa.models.inline_response20072 import InlineResponse20072
from Vpsa.models.inline_response20072_response import InlineResponse20072Response
from Vpsa.models.inline_response20072_response_volumes import InlineResponse20072ResponseVolumes
from Vpsa.models.inline_response20073 import InlineResponse20073
from Vpsa.models.inline_response20073_response import InlineResponse20073Response
from Vpsa.models.inline_response20074 import InlineResponse20074
from Vpsa.models.inline_response20074_response import InlineResponse20074Response
from Vpsa.models.inline_response20075 import InlineResponse20075
from Vpsa.models.inline_response20075_response import InlineResponse20075Response
from Vpsa.models.inline_response20076 import InlineResponse20076
from Vpsa.models.inline_response20076_response import InlineResponse20076Response
from Vpsa.models.inline_response20077 import InlineResponse20077
from Vpsa.models.inline_response20077_response import InlineResponse20077Response
from Vpsa.models.inline_response20078 import InlineResponse20078
from Vpsa.models.inline_response20078_response import InlineResponse20078Response
from Vpsa.models.inline_response20078_response_volumes import InlineResponse20078ResponseVolumes
from Vpsa.models.inline_response20079 import InlineResponse20079
from Vpsa.models.inline_response20079_response import InlineResponse20079Response
from Vpsa.models.inline_response20079_response_volume_capacity import InlineResponse20079ResponseVolumeCapacity
from Vpsa.models.inline_response2007_response import InlineResponse2007Response
from Vpsa.models.inline_response2008 import InlineResponse2008
from Vpsa.models.inline_response20080 import InlineResponse20080
from Vpsa.models.inline_response20080_response import InlineResponse20080Response
from Vpsa.models.inline_response20081 import InlineResponse20081
from Vpsa.models.inline_response20081_response import InlineResponse20081Response
from Vpsa.models.inline_response20082 import InlineResponse20082
from Vpsa.models.inline_response20082_response import InlineResponse20082Response
from Vpsa.models.inline_response20082_response_volumes import InlineResponse20082ResponseVolumes
from Vpsa.models.inline_response20083 import InlineResponse20083
from Vpsa.models.inline_response20083_response import InlineResponse20083Response
from Vpsa.models.inline_response20083_response_usages import InlineResponse20083ResponseUsages
from Vpsa.models.inline_response20084 import InlineResponse20084
from Vpsa.models.inline_response20084_response import InlineResponse20084Response
from Vpsa.models.inline_response20084_response_raid_groups import InlineResponse20084ResponseRaidGroups
from Vpsa.models.inline_response20085 import InlineResponse20085
from Vpsa.models.inline_response20085_response import InlineResponse20085Response
from Vpsa.models.inline_response20086 import InlineResponse20086
from Vpsa.models.inline_response20086_response import InlineResponse20086Response
from Vpsa.models.inline_response20086_response_raid_group import InlineResponse20086ResponseRaidGroup
from Vpsa.models.inline_response20086_response_raid_group_volumes import InlineResponse20086ResponseRaidGroupVolumes
from Vpsa.models.inline_response20087 import InlineResponse20087
from Vpsa.models.inline_response20087_response import InlineResponse20087Response
from Vpsa.models.inline_response20088 import InlineResponse20088
from Vpsa.models.inline_response20088_raid_groups import InlineResponse20088RaidGroups
from Vpsa.models.inline_response20089 import InlineResponse20089
from Vpsa.models.inline_response20089_response import InlineResponse20089Response
from Vpsa.models.inline_response20089_response_disks import InlineResponse20089ResponseDisks
from Vpsa.models.inline_response2008_response import InlineResponse2008Response
from Vpsa.models.inline_response2008_response_container import InlineResponse2008ResponseContainer
from Vpsa.models.inline_response2009 import InlineResponse2009
from Vpsa.models.inline_response20090 import InlineResponse20090
from Vpsa.models.inline_response20090_response import InlineResponse20090Response
from Vpsa.models.inline_response20091 import InlineResponse20091
from Vpsa.models.inline_response20091_response import InlineResponse20091Response
from Vpsa.models.inline_response20092 import InlineResponse20092
from Vpsa.models.inline_response20092_response import InlineResponse20092Response
from Vpsa.models.inline_response20093 import InlineResponse20093
from Vpsa.models.inline_response20093_response import InlineResponse20093Response
from Vpsa.models.inline_response20094 import InlineResponse20094
from Vpsa.models.inline_response20094_response import InlineResponse20094Response
from Vpsa.models.inline_response20095 import InlineResponse20095
from Vpsa.models.inline_response20095_response import InlineResponse20095Response
from Vpsa.models.inline_response20096 import InlineResponse20096
from Vpsa.models.inline_response20096_response import InlineResponse20096Response
from Vpsa.models.inline_response20097 import InlineResponse20097
from Vpsa.models.inline_response20097_response import InlineResponse20097Response
from Vpsa.models.inline_response20097_response_usages import InlineResponse20097ResponseUsages
from Vpsa.models.inline_response20098 import InlineResponse20098
from Vpsa.models.inline_response20098_response import InlineResponse20098Response
from Vpsa.models.inline_response20098_response_dst import InlineResponse20098ResponseDst
from Vpsa.models.inline_response20098_response_src import InlineResponse20098ResponseSrc
from Vpsa.models.inline_response20098_response_vpsa_mirror_jobs import InlineResponse20098ResponseVpsaMirrorJobs
from Vpsa.models.inline_response20099 import InlineResponse20099
from Vpsa.models.inline_response20099_response import InlineResponse20099Response
from Vpsa.models.inline_response20099_response_vpsa_mirror_job import InlineResponse20099ResponseVpsaMirrorJob
from Vpsa.models.inline_response20099_response_vpsa_mirror_job_dst import InlineResponse20099ResponseVpsaMirrorJobDst
from Vpsa.models.inline_response20099_response_vpsa_mirror_job_src import InlineResponse20099ResponseVpsaMirrorJobSrc
from Vpsa.models.inline_response2009_response import InlineResponse2009Response
from Vpsa.models.inline_response200_response import InlineResponse200Response
from Vpsa.models.inline_response200_response_snapshot_set_name import InlineResponse200ResponseSnapshotSetName
from Vpsa.models.issue_user_temp_code import IssueUserTempCode
from Vpsa.models.join_active_directory import JoinActiveDirectory
from Vpsa.models.leave_active_directory import LeaveActiveDirectory
from Vpsa.models.migrate_volume import MigrateVolume
from Vpsa.models.migrate_zcs_image_repository import MigrateZcsImageRepository
from Vpsa.models.pause_flc_policy_on_volume import PauseFlcPolicyOnVolume
from Vpsa.models.pause_volume_snapshot_policy import PauseVolumeSnapshotPolicy
from Vpsa.models.remove_directories_from_quota_project import RemoveDirectoriesFromQuotaProject
from Vpsa.models.rename_category import RenameCategory
from Vpsa.models.rename_drive import RenameDrive
from Vpsa.models.rename_pool import RenamePool
from Vpsa.models.rename_raid_group import RenameRaidGroup
from Vpsa.models.rename_server import RenameServer
from Vpsa.models.rename_snapshot_policy import RenameSnapshotPolicy
from Vpsa.models.rename_volume import RenameVolume
from Vpsa.models.replace_drive import ReplaceDrive
from Vpsa.models.replace_ros_backup_job_snapshot_policy import ReplaceRosBackupJobSnapshotPolicy
from Vpsa.models.reset_user_access_key import ResetUserAccessKey
from Vpsa.models.restore_active_directory import RestoreActiveDirectory
from Vpsa.models.restore_aws_kms_store import RestoreAwsKmsStore
from Vpsa.models.restore_encryption_password import RestoreEncryptionPassword
from Vpsa.models.restore_encryption_password_kmip import RestoreEncryptionPasswordKmip
from Vpsa.models.resume_broken_mirror import ResumeBrokenMirror
from Vpsa.models.resume_flc_policy_on_volume import ResumeFlcPolicyOnVolume
from Vpsa.models.set_encription_pass import SetEncriptionPass
from Vpsa.models.set_encription_pass_or_use_aws_kms_store import SetEncriptionPassOrUseAwsKmsStore
from Vpsa.models.set_encryption_password_kmip import SetEncryptionPasswordKmip
from Vpsa.models.set_global_server_connectivity_monitoring import SetGlobalServerConnectivityMonitoring
from Vpsa.models.set_iscsi_over_public_ip import SetIscsiOverPublicIp
from Vpsa.models.set_multizone_read_mode import SetMultizoneReadMode
from Vpsa.models.set_nfs_domain import SetNfsDomain
from Vpsa.models.set_obs_backup_job_class import SetObsBackupJobClass
from Vpsa.models.set_pass_policy import SetPassPolicy
from Vpsa.models.set_pool_cache import SetPoolCache
from Vpsa.models.set_pool_cowcache import SetPoolCowcache
from Vpsa.models.set_recycle_bin import SetRecycleBin
from Vpsa.models.set_smb_charset import SetSmbCharset
from Vpsa.models.set_smb_netbios_name import SetSmbNetbiosName
from Vpsa.models.set_smb_trusted_domains import SetSmbTrustedDomains
from Vpsa.models.set_volume_attach_permissions import SetVolumeAttachPermissions
from Vpsa.models.set_volume_export_name import SetVolumeExportName
from Vpsa.models.show_remote_snapshots_on_cg import ShowRemoteSnapshotsOnCg
from Vpsa.models.shred_drive import ShredDrive
from Vpsa.models.shrink_pool import ShrinkPool
from Vpsa.models.suspend_cgs_for_snapshot_set import SuspendCgsForSnapshotSet
from Vpsa.models.switch_remote_clone_mode import SwitchRemoteCloneMode
from Vpsa.models.update_category import UpdateCategory
from Vpsa.models.update_flc_policy import UpdateFlcPolicy
from Vpsa.models.update_flc_policy_scheduling import UpdateFlcPolicyScheduling
from Vpsa.models.update_flc_recycle_bin import UpdateFlcRecycleBin
from Vpsa.models.update_mirror_rate_limit import UpdateMirrorRateLimit
from Vpsa.models.update_mirror_wan_optimization import UpdateMirrorWanOptimization
from Vpsa.models.update_pool_capacity_alerts import UpdatePoolCapacityAlerts
from Vpsa.models.update_protection import UpdateProtection
from Vpsa.models.update_quota_limit import UpdateQuotaLimit
from Vpsa.models.update_raid_group_resync_speed import UpdateRaidGroupResyncSpeed
from Vpsa.models.update_remote_vpsa_rate import UpdateRemoteVpsaRate
from Vpsa.models.update_role import UpdateRole
from Vpsa.models.update_ros_destination import UpdateRosDestination
from Vpsa.models.update_server import UpdateServer
from Vpsa.models.update_snapshot_policy import UpdateSnapshotPolicy
from Vpsa.models.update_ssd_cool_off import UpdateSsdCoolOff
from Vpsa.models.update_user_info import UpdateUserInfo
from Vpsa.models.update_user_roles import UpdateUserRoles
from Vpsa.models.update_vol_perf_threshold import UpdateVolPerfThreshold
from Vpsa.models.update_volume_nas_options import UpdateVolumeNasOptions
from Vpsa.models.update_volume_quotas_state import UpdateVolumeQuotasState
from Vpsa.models.update_zcs_settings import UpdateZcsSettings
from Vpsa.models.volumesidquotas_json_quotas import VolumesidquotasJsonQuotas



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class GetAllSnapshots(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'start': 'int',
        'limit': 'int',
        'application': 'str',
        'jobname': 'str',
        'snapshot_policy': 'str',
        'start_date': 'str',
        'end_date': 'str'
    }

    attribute_map = {
        'start': 'start',
        'limit': 'limit',
        'application': 'application',
        'jobname': 'jobname',
        'snapshot_policy': 'snapshot_policy',
        'start_date': 'start_date',
        'end_date': 'end_date'
    }

    def __init__(self, start=None, limit=None, application=None, jobname=None, snapshot_policy=None, start_date=None, end_date=None, _configuration=None):  # noqa: E501
        """GetAllSnapshots - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._start = None
        self._limit = None
        self._application = None
        self._jobname = None
        self._snapshot_policy = None
        self._start_date = None
        self._end_date = None
        self.discriminator = None

        if start is not None:
            self.start = start
        if limit is not None:
            self.limit = limit
        if application is not None:
            self.application = application
        if jobname is not None:
            self.jobname = jobname
        if snapshot_policy is not None:
            self.snapshot_policy = snapshot_policy
        if start_date is not None:
            self.start_date = start_date
        if end_date is not None:
            self.end_date = end_date

    @property
    def start(self):
        """Gets the start of this GetAllSnapshots.  # noqa: E501

        The item number to start from. 0 starts from the beginning.  # noqa: E501

        :return: The start of this GetAllSnapshots.  # noqa: E501
        :rtype: int
        """
        return self._start

    @start.setter
    def start(self, start):
        """Sets the start of this GetAllSnapshots.

        The item number to start from. 0 starts from the beginning.  # noqa: E501

        :param start: The start of this GetAllSnapshots.  # noqa: E501
        :type: int
        """
        if (self._configuration.client_side_validation and
                start is not None and start < 0):  # noqa: E501
            raise ValueError("Invalid value for `start`, must be a value greater than or equal to `0`")  # noqa: E501

        self._start = start

    @property
    def limit(self):
        """Gets the limit of this GetAllSnapshots.  # noqa: E501

        The total number of records to return.  # noqa: E501

        :return: The limit of this GetAllSnapshots.  # noqa: E501
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this GetAllSnapshots.

        The total number of records to return.  # noqa: E501

        :param limit: The limit of this GetAllSnapshots.  # noqa: E501
        :type: int
        """

        self._limit = limit

    @property
    def application(self):
        """Gets the application of this GetAllSnapshots.  # noqa: E501

        Policy Application.  # noqa: E501

        :return: The application of this GetAllSnapshots.  # noqa: E501
        :rtype: str
        """
        return self._application

    @application.setter
    def application(self, application):
        """Sets the application of this GetAllSnapshots.

        Policy Application.  # noqa: E501

        :param application: The application of this GetAllSnapshots.  # noqa: E501
        :type: str
        """
        allowed_values = ["user", "mirror", "migration", "obs_mirror", "shadow_copy"]  # noqa: E501
        if (self._configuration.client_side_validation and
                application not in allowed_values):
            raise ValueError(
                "Invalid value for `application` ({0}), must be one of {1}"  # noqa: E501
                .format(application, allowed_values)
            )

        self._application = application

    @property
    def jobname(self):
        """Gets the jobname of this GetAllSnapshots.  # noqa: E501

        Mirror Job used to create the snapshots.  # noqa: E501

        :return: The jobname of this GetAllSnapshots.  # noqa: E501
        :rtype: str
        """
        return self._jobname

    @jobname.setter
    def jobname(self, jobname):
        """Sets the jobname of this GetAllSnapshots.

        Mirror Job used to create the snapshots.  # noqa: E501

        :param jobname: The jobname of this GetAllSnapshots.  # noqa: E501
        :type: str
        """
        if (self._configuration.client_side_validation and
                jobname is not None and not re.search(r'^bkpjobs-[0-9a-f]{8}$', jobname)):  # noqa: E501
            raise ValueError(r"Invalid value for `jobname`, must be a follow pattern or equal to `/^bkpjobs-[0-9a-f]{8}$/`")  # noqa: E501

        self._jobname = jobname

    @property
    def snapshot_policy(self):
        """Gets the snapshot_policy of this GetAllSnapshots.  # noqa: E501

        Snapshot Policy which created the snapshots.  # noqa: E501

        :return: The snapshot_policy of this GetAllSnapshots.  # noqa: E501
        :rtype: str
        """
        return self._snapshot_policy

    @snapshot_policy.setter
    def snapshot_policy(self, snapshot_policy):
        """Sets the snapshot_policy of this GetAllSnapshots.

        Snapshot Policy which created the snapshots.  # noqa: E501

        :param snapshot_policy: The snapshot_policy of this GetAllSnapshots.  # noqa: E501
        :type: str
        """

        self._snapshot_policy = snapshot_policy

    @property
    def start_date(self):
        """Gets the start_date of this GetAllSnapshots.  # noqa: E501

        Snapshots created after the provided value (DD:MM:YY:HH:MM:SS localtime)  # noqa: E501

        :return: The start_date of this GetAllSnapshots.  # noqa: E501
        :rtype: str
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this GetAllSnapshots.

        Snapshots created after the provided value (DD:MM:YY:HH:MM:SS localtime)  # noqa: E501

        :param start_date: The start_date of this GetAllSnapshots.  # noqa: E501
        :type: str
        """

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this GetAllSnapshots.  # noqa: E501

        Snapshots created before the provided value DD:MM:YY:HH:MM:SS localtime)  # noqa: E501

        :return: The end_date of this GetAllSnapshots.  # noqa: E501
        :rtype: str
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this GetAllSnapshots.

        Snapshots created before the provided value DD:MM:YY:HH:MM:SS localtime)  # noqa: E501

        :param end_date: The end_date of this GetAllSnapshots.  # noqa: E501
        :type: str
        """

        self._end_date = end_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetAllSnapshots, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetAllSnapshots):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GetAllSnapshots):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara Provisioning Portal API

     # Overview  This document outlines the methods available for creation and high-level administration of Zadara Storage VPSAs via a Zadara Storage Provisioning Portal. This API supports form-encoded requests, and can return either JSON or XML responses.  ## Endpoint  The base URL for the requests is the Provisioning Portal URL you created your VPSA through - for example: https://manage.zadarastorage.com/, and all APIs will be prefixed with /api as noted in the documentation below.  ## Authentication  To use this API, an authentication token is required. The API for retrieving this token can be found below in the Authentication section. You may pass this token in requests either via the the X-Token header or via basic authentication (base64 encoded) in Authorization header.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from ProvisioningPortal.configuration import Configuration


class UpdateObjectAccount(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'account_name': 'str',
        'admin_username': 'str',
        'admin_password': 'str',
        'ip': 'str',
        'host': 'str',
        'auto_approve': 'bool'
    }

    attribute_map = {
        'account_name': 'account_name',
        'admin_username': 'admin_username',
        'admin_password': 'admin_password',
        'ip': 'ip',
        'host': 'host',
        'auto_approve': 'auto_approve'
    }

    def __init__(self, account_name=None, admin_username=None, admin_password=None, ip=None, host=None, auto_approve=None, _configuration=None):  # noqa: E501
        """UpdateObjectAccount - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._account_name = None
        self._admin_username = None
        self._admin_password = None
        self._ip = None
        self._host = None
        self._auto_approve = None
        self.discriminator = None

        if account_name is not None:
            self.account_name = account_name
        if admin_username is not None:
            self.admin_username = admin_username
        if admin_password is not None:
            self.admin_password = admin_password
        if ip is not None:
            self.ip = ip
        if host is not None:
            self.host = host
        if auto_approve is not None:
            self.auto_approve = auto_approve

    @property
    def account_name(self):
        """Gets the account_name of this UpdateObjectAccount.  # noqa: E501

        The Object Storage admin account.  # noqa: E501

        :return: The account_name of this UpdateObjectAccount.  # noqa: E501
        :rtype: str
        """
        return self._account_name

    @account_name.setter
    def account_name(self, account_name):
        """Sets the account_name of this UpdateObjectAccount.

        The Object Storage admin account.  # noqa: E501

        :param account_name: The account_name of this UpdateObjectAccount.  # noqa: E501
        :type: str
        """

        self._account_name = account_name

    @property
    def admin_username(self):
        """Gets the admin_username of this UpdateObjectAccount.  # noqa: E501

        The Object Storage admin username.  # noqa: E501

        :return: The admin_username of this UpdateObjectAccount.  # noqa: E501
        :rtype: str
        """
        return self._admin_username

    @admin_username.setter
    def admin_username(self, admin_username):
        """Sets the admin_username of this UpdateObjectAccount.

        The Object Storage admin username.  # noqa: E501

        :param admin_username: The admin_username of this UpdateObjectAccount.  # noqa: E501
        :type: str
        """

        self._admin_username = admin_username

    @property
    def admin_password(self):
        """Gets the admin_password of this UpdateObjectAccount.  # noqa: E501

        The Object Storage admin password.  # noqa: E501

        :return: The admin_password of this UpdateObjectAccount.  # noqa: E501
        :rtype: str
        """
        return self._admin_password

    @admin_password.setter
    def admin_password(self, admin_password):
        """Sets the admin_password of this UpdateObjectAccount.

        The Object Storage admin password.  # noqa: E501

        :param admin_password: The admin_password of this UpdateObjectAccount.  # noqa: E501
        :type: str
        """

        self._admin_password = admin_password

    @property
    def ip(self):
        """Gets the ip of this UpdateObjectAccount.  # noqa: E501

        The Object Storage ip and port.  # noqa: E501

        :return: The ip of this UpdateObjectAccount.  # noqa: E501
        :rtype: str
        """
        return self._ip

    @ip.setter
    def ip(self, ip):
        """Sets the ip of this UpdateObjectAccount.

        The Object Storage ip and port.  # noqa: E501

        :param ip: The ip of this UpdateObjectAccount.  # noqa: E501
        :type: str
        """

        self._ip = ip

    @property
    def host(self):
        """Gets the host of this UpdateObjectAccount.  # noqa: E501

        The Object Storage host name.  # noqa: E501

        :return: The host of this UpdateObjectAccount.  # noqa: E501
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this UpdateObjectAccount.

        The Object Storage host name.  # noqa: E501

        :param host: The host of this UpdateObjectAccount.  # noqa: E501
        :type: str
        """

        self._host = host

    @property
    def auto_approve(self):
        """Gets the auto_approve of this UpdateObjectAccount.  # noqa: E501

        Indicates wether to automatically approve account creation requests.  # noqa: E501

        :return: The auto_approve of this UpdateObjectAccount.  # noqa: E501
        :rtype: bool
        """
        return self._auto_approve

    @auto_approve.setter
    def auto_approve(self, auto_approve):
        """Sets the auto_approve of this UpdateObjectAccount.

        Indicates wether to automatically approve account creation requests.  # noqa: E501

        :param auto_approve: The auto_approve of this UpdateObjectAccount.  # noqa: E501
        :type: bool
        """

        self._auto_approve = auto_approve

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateObjectAccount, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateObjectAccount):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateObjectAccount):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse20087Vlans(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'comment': 'str',
        'tenants': 'list[int]',
        'allocated': 'bool',
        'reserved': 'bool',
        'vlan_id': 'int',
        'all_vrids': 'str'
    }

    attribute_map = {
        'comment': 'comment',
        'tenants': 'tenants',
        'allocated': 'allocated',
        'reserved': 'reserved',
        'vlan_id': 'vlan_id',
        'all_vrids': 'all_vrids'
    }

    def __init__(self, comment=None, tenants=None, allocated=None, reserved=None, vlan_id=None, all_vrids=None, _configuration=None):  # noqa: E501
        """InlineResponse20087Vlans - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._comment = None
        self._tenants = None
        self._allocated = None
        self._reserved = None
        self._vlan_id = None
        self._all_vrids = None
        self.discriminator = None

        if comment is not None:
            self.comment = comment
        if tenants is not None:
            self.tenants = tenants
        if allocated is not None:
            self.allocated = allocated
        if reserved is not None:
            self.reserved = reserved
        if vlan_id is not None:
            self.vlan_id = vlan_id
        if all_vrids is not None:
            self.all_vrids = all_vrids

    @property
    def comment(self):
        """Gets the comment of this InlineResponse20087Vlans.  # noqa: E501


        :return: The comment of this InlineResponse20087Vlans.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this InlineResponse20087Vlans.


        :param comment: The comment of this InlineResponse20087Vlans.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def tenants(self):
        """Gets the tenants of this InlineResponse20087Vlans.  # noqa: E501


        :return: The tenants of this InlineResponse20087Vlans.  # noqa: E501
        :rtype: list[int]
        """
        return self._tenants

    @tenants.setter
    def tenants(self, tenants):
        """Sets the tenants of this InlineResponse20087Vlans.


        :param tenants: The tenants of this InlineResponse20087Vlans.  # noqa: E501
        :type: list[int]
        """

        self._tenants = tenants

    @property
    def allocated(self):
        """Gets the allocated of this InlineResponse20087Vlans.  # noqa: E501


        :return: The allocated of this InlineResponse20087Vlans.  # noqa: E501
        :rtype: bool
        """
        return self._allocated

    @allocated.setter
    def allocated(self, allocated):
        """Sets the allocated of this InlineResponse20087Vlans.


        :param allocated: The allocated of this InlineResponse20087Vlans.  # noqa: E501
        :type: bool
        """

        self._allocated = allocated

    @property
    def reserved(self):
        """Gets the reserved of this InlineResponse20087Vlans.  # noqa: E501


        :return: The reserved of this InlineResponse20087Vlans.  # noqa: E501
        :rtype: bool
        """
        return self._reserved

    @reserved.setter
    def reserved(self, reserved):
        """Sets the reserved of this InlineResponse20087Vlans.


        :param reserved: The reserved of this InlineResponse20087Vlans.  # noqa: E501
        :type: bool
        """

        self._reserved = reserved

    @property
    def vlan_id(self):
        """Gets the vlan_id of this InlineResponse20087Vlans.  # noqa: E501


        :return: The vlan_id of this InlineResponse20087Vlans.  # noqa: E501
        :rtype: int
        """
        return self._vlan_id

    @vlan_id.setter
    def vlan_id(self, vlan_id):
        """Sets the vlan_id of this InlineResponse20087Vlans.


        :param vlan_id: The vlan_id of this InlineResponse20087Vlans.  # noqa: E501
        :type: int
        """

        self._vlan_id = vlan_id

    @property
    def all_vrids(self):
        """Gets the all_vrids of this InlineResponse20087Vlans.  # noqa: E501


        :return: The all_vrids of this InlineResponse20087Vlans.  # noqa: E501
        :rtype: str
        """
        return self._all_vrids

    @all_vrids.setter
    def all_vrids(self, all_vrids):
        """Sets the all_vrids of this InlineResponse20087Vlans.


        :param all_vrids: The all_vrids of this InlineResponse20087Vlans.  # noqa: E501
        :type: str
        """

        self._all_vrids = all_vrids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20087Vlans, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20087Vlans):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20087Vlans):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Object Storage REST API

    # Overview  This document outlines the methods available for administrating your VPSA&#174; Object Storage. The API supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or through the X-Access-Key header. Alternately, you can use the username and password parameters for authentication, but we do not recommend this method for anything other than possibly retrieving an API key.  By default , all operations are allowed only to VPSA Object Storage admin. Some actions are allowed by an account admin and they will be marked on the action's header  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some time to complete. When using the API, this can cause some actions, such as adding drives to storage policy, to be undesirably asynchronous. You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Metering API  Metering information can be retrieved using the VPSA Object Storage API for the following components:  - Accounts - Users - Drives - Virtual Controllers - Load Balancer Groups - Storage Policies  Metering information returned by the API is subject to the following constraints:  - 10 seconds interval - 1 hour range - 1 minute interval - 1 day range - 1 hour interval - 30 days range  Values outside the accepted range will be returned as 0.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Zios.configuration import Configuration


class InlineResponse20016ResponseDisk(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'display_name': 'str',
        'disk_type': 'str',
        'disk_uuid': 'str',
        'storage_node': 'str',
        'vc': 'str',
        'region_id': 'int',
        'zone_id': 'int',
        'policy_type': 'int',
        'allocation_zone': 'str',
        'allocation_zone_display_name': 'str',
        'storage_policy': 'str',
        'capacity_protection': 'str',
        'status': 'str',
        'capacity': 'int',
        'partition_count_degraded': 'int',
        'partition_count_critical': 'int',
        'created_at': 'str',
        'modified_at': 'str',
        'percentage_added': 'int'
    }

    attribute_map = {
        'name': 'name',
        'display_name': 'display_name',
        'disk_type': 'disk_type',
        'disk_uuid': 'disk_uuid',
        'storage_node': 'storage_node',
        'vc': 'vc',
        'region_id': 'region_id',
        'zone_id': 'zone_id',
        'policy_type': 'policy_type',
        'allocation_zone': 'allocation-zone',
        'allocation_zone_display_name': 'allocation-zone_display_name',
        'storage_policy': 'storage_policy',
        'capacity_protection': 'capacity_protection',
        'status': 'status',
        'capacity': 'capacity',
        'partition_count_degraded': 'partition_count_degraded',
        'partition_count_critical': 'partition_count_critical',
        'created_at': 'created_at',
        'modified_at': 'modified_at',
        'percentage_added': 'percentage_added'
    }

    def __init__(self, name=None, display_name=None, disk_type=None, disk_uuid=None, storage_node=None, vc=None, region_id=None, zone_id=None, policy_type=None, allocation_zone=None, allocation_zone_display_name=None, storage_policy=None, capacity_protection=None, status=None, capacity=None, partition_count_degraded=None, partition_count_critical=None, created_at=None, modified_at=None, percentage_added=None, _configuration=None):  # noqa: E501
        """InlineResponse20016ResponseDisk - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._display_name = None
        self._disk_type = None
        self._disk_uuid = None
        self._storage_node = None
        self._vc = None
        self._region_id = None
        self._zone_id = None
        self._policy_type = None
        self._allocation_zone = None
        self._allocation_zone_display_name = None
        self._storage_policy = None
        self._capacity_protection = None
        self._status = None
        self._capacity = None
        self._partition_count_degraded = None
        self._partition_count_critical = None
        self._created_at = None
        self._modified_at = None
        self._percentage_added = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if display_name is not None:
            self.display_name = display_name
        if disk_type is not None:
            self.disk_type = disk_type
        if disk_uuid is not None:
            self.disk_uuid = disk_uuid
        if storage_node is not None:
            self.storage_node = storage_node
        if vc is not None:
            self.vc = vc
        if region_id is not None:
            self.region_id = region_id
        if zone_id is not None:
            self.zone_id = zone_id
        if policy_type is not None:
            self.policy_type = policy_type
        if allocation_zone is not None:
            self.allocation_zone = allocation_zone
        if allocation_zone_display_name is not None:
            self.allocation_zone_display_name = allocation_zone_display_name
        if storage_policy is not None:
            self.storage_policy = storage_policy
        if capacity_protection is not None:
            self.capacity_protection = capacity_protection
        if status is not None:
            self.status = status
        if capacity is not None:
            self.capacity = capacity
        if partition_count_degraded is not None:
            self.partition_count_degraded = partition_count_degraded
        if partition_count_critical is not None:
            self.partition_count_critical = partition_count_critical
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at
        if percentage_added is not None:
            self.percentage_added = percentage_added

    @property
    def name(self):
        """Gets the name of this InlineResponse20016ResponseDisk.  # noqa: E501


        :return: The name of this InlineResponse20016ResponseDisk.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse20016ResponseDisk.


        :param name: The name of this InlineResponse20016ResponseDisk.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def display_name(self):
        """Gets the display_name of this InlineResponse20016ResponseDisk.  # noqa: E501


        :return: The display_name of this InlineResponse20016ResponseDisk.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this InlineResponse20016ResponseDisk.


        :param display_name: The display_name of this InlineResponse20016ResponseDisk.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def disk_type(self):
        """Gets the disk_type of this InlineResponse20016ResponseDisk.  # noqa: E501


        :return: The disk_type of this InlineResponse20016ResponseDisk.  # noqa: E501
        :rtype: str
        """
        return self._disk_type

    @disk_type.setter
    def disk_type(self, disk_type):
        """Sets the disk_type of this InlineResponse20016ResponseDisk.


        :param disk_type: The disk_type of this InlineResponse20016ResponseDisk.  # noqa: E501
        :type: str
        """

        self._disk_type = disk_type

    @property
    def disk_uuid(self):
        """Gets the disk_uuid of this InlineResponse20016ResponseDisk.  # noqa: E501


        :return: The disk_uuid of this InlineResponse20016ResponseDisk.  # noqa: E501
        :rtype: str
        """
        return self._disk_uuid

    @disk_uuid.setter
    def disk_uuid(self, disk_uuid):
        """Sets the disk_uuid of this InlineResponse20016ResponseDisk.


        :param disk_uuid: The disk_uuid of this InlineResponse20016ResponseDisk.  # noqa: E501
        :type: str
        """

        self._disk_uuid = disk_uuid

    @property
    def storage_node(self):
        """Gets the storage_node of this InlineResponse20016ResponseDisk.  # noqa: E501


        :return: The storage_node of this InlineResponse20016ResponseDisk.  # noqa: E501
        :rtype: str
        """
        return self._storage_node

    @storage_node.setter
    def storage_node(self, storage_node):
        """Sets the storage_node of this InlineResponse20016ResponseDisk.


        :param storage_node: The storage_node of this InlineResponse20016ResponseDisk.  # noqa: E501
        :type: str
        """

        self._storage_node = storage_node

    @property
    def vc(self):
        """Gets the vc of this InlineResponse20016ResponseDisk.  # noqa: E501


        :return: The vc of this InlineResponse20016ResponseDisk.  # noqa: E501
        :rtype: str
        """
        return self._vc

    @vc.setter
    def vc(self, vc):
        """Sets the vc of this InlineResponse20016ResponseDisk.


        :param vc: The vc of this InlineResponse20016ResponseDisk.  # noqa: E501
        :type: str
        """

        self._vc = vc

    @property
    def region_id(self):
        """Gets the region_id of this InlineResponse20016ResponseDisk.  # noqa: E501


        :return: The region_id of this InlineResponse20016ResponseDisk.  # noqa: E501
        :rtype: int
        """
        return self._region_id

    @region_id.setter
    def region_id(self, region_id):
        """Sets the region_id of this InlineResponse20016ResponseDisk.


        :param region_id: The region_id of this InlineResponse20016ResponseDisk.  # noqa: E501
        :type: int
        """

        self._region_id = region_id

    @property
    def zone_id(self):
        """Gets the zone_id of this InlineResponse20016ResponseDisk.  # noqa: E501


        :return: The zone_id of this InlineResponse20016ResponseDisk.  # noqa: E501
        :rtype: int
        """
        return self._zone_id

    @zone_id.setter
    def zone_id(self, zone_id):
        """Sets the zone_id of this InlineResponse20016ResponseDisk.


        :param zone_id: The zone_id of this InlineResponse20016ResponseDisk.  # noqa: E501
        :type: int
        """

        self._zone_id = zone_id

    @property
    def policy_type(self):
        """Gets the policy_type of this InlineResponse20016ResponseDisk.  # noqa: E501


        :return: The policy_type of this InlineResponse20016ResponseDisk.  # noqa: E501
        :rtype: int
        """
        return self._policy_type

    @policy_type.setter
    def policy_type(self, policy_type):
        """Sets the policy_type of this InlineResponse20016ResponseDisk.


        :param policy_type: The policy_type of this InlineResponse20016ResponseDisk.  # noqa: E501
        :type: int
        """

        self._policy_type = policy_type

    @property
    def allocation_zone(self):
        """Gets the allocation_zone of this InlineResponse20016ResponseDisk.  # noqa: E501


        :return: The allocation_zone of this InlineResponse20016ResponseDisk.  # noqa: E501
        :rtype: str
        """
        return self._allocation_zone

    @allocation_zone.setter
    def allocation_zone(self, allocation_zone):
        """Sets the allocation_zone of this InlineResponse20016ResponseDisk.


        :param allocation_zone: The allocation_zone of this InlineResponse20016ResponseDisk.  # noqa: E501
        :type: str
        """

        self._allocation_zone = allocation_zone

    @property
    def allocation_zone_display_name(self):
        """Gets the allocation_zone_display_name of this InlineResponse20016ResponseDisk.  # noqa: E501


        :return: The allocation_zone_display_name of this InlineResponse20016ResponseDisk.  # noqa: E501
        :rtype: str
        """
        return self._allocation_zone_display_name

    @allocation_zone_display_name.setter
    def allocation_zone_display_name(self, allocation_zone_display_name):
        """Sets the allocation_zone_display_name of this InlineResponse20016ResponseDisk.


        :param allocation_zone_display_name: The allocation_zone_display_name of this InlineResponse20016ResponseDisk.  # noqa: E501
        :type: str
        """

        self._allocation_zone_display_name = allocation_zone_display_name

    @property
    def storage_policy(self):
        """Gets the storage_policy of this InlineResponse20016ResponseDisk.  # noqa: E501


        :return: The storage_policy of this InlineResponse20016ResponseDisk.  # noqa: E501
        :rtype: str
        """
        return self._storage_policy

    @storage_policy.setter
    def storage_policy(self, storage_policy):
        """Sets the storage_policy of this InlineResponse20016ResponseDisk.


        :param storage_policy: The storage_policy of this InlineResponse20016ResponseDisk.  # noqa: E501
        :type: str
        """

        self._storage_policy = storage_policy

    @property
    def capacity_protection(self):
        """Gets the capacity_protection of this InlineResponse20016ResponseDisk.  # noqa: E501


        :return: The capacity_protection of this InlineResponse20016ResponseDisk.  # noqa: E501
        :rtype: str
        """
        return self._capacity_protection

    @capacity_protection.setter
    def capacity_protection(self, capacity_protection):
        """Sets the capacity_protection of this InlineResponse20016ResponseDisk.


        :param capacity_protection: The capacity_protection of this InlineResponse20016ResponseDisk.  # noqa: E501
        :type: str
        """

        self._capacity_protection = capacity_protection

    @property
    def status(self):
        """Gets the status of this InlineResponse20016ResponseDisk.  # noqa: E501


        :return: The status of this InlineResponse20016ResponseDisk.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InlineResponse20016ResponseDisk.


        :param status: The status of this InlineResponse20016ResponseDisk.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def capacity(self):
        """Gets the capacity of this InlineResponse20016ResponseDisk.  # noqa: E501


        :return: The capacity of this InlineResponse20016ResponseDisk.  # noqa: E501
        :rtype: int
        """
        return self._capacity

    @capacity.setter
    def capacity(self, capacity):
        """Sets the capacity of this InlineResponse20016ResponseDisk.


        :param capacity: The capacity of this InlineResponse20016ResponseDisk.  # noqa: E501
        :type: int
        """

        self._capacity = capacity

    @property
    def partition_count_degraded(self):
        """Gets the partition_count_degraded of this InlineResponse20016ResponseDisk.  # noqa: E501


        :return: The partition_count_degraded of this InlineResponse20016ResponseDisk.  # noqa: E501
        :rtype: int
        """
        return self._partition_count_degraded

    @partition_count_degraded.setter
    def partition_count_degraded(self, partition_count_degraded):
        """Sets the partition_count_degraded of this InlineResponse20016ResponseDisk.


        :param partition_count_degraded: The partition_count_degraded of this InlineResponse20016ResponseDisk.  # noqa: E501
        :type: int
        """

        self._partition_count_degraded = partition_count_degraded

    @property
    def partition_count_critical(self):
        """Gets the partition_count_critical of this InlineResponse20016ResponseDisk.  # noqa: E501


        :return: The partition_count_critical of this InlineResponse20016ResponseDisk.  # noqa: E501
        :rtype: int
        """
        return self._partition_count_critical

    @partition_count_critical.setter
    def partition_count_critical(self, partition_count_critical):
        """Sets the partition_count_critical of this InlineResponse20016ResponseDisk.


        :param partition_count_critical: The partition_count_critical of this InlineResponse20016ResponseDisk.  # noqa: E501
        :type: int
        """

        self._partition_count_critical = partition_count_critical

    @property
    def created_at(self):
        """Gets the created_at of this InlineResponse20016ResponseDisk.  # noqa: E501


        :return: The created_at of this InlineResponse20016ResponseDisk.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InlineResponse20016ResponseDisk.


        :param created_at: The created_at of this InlineResponse20016ResponseDisk.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this InlineResponse20016ResponseDisk.  # noqa: E501


        :return: The modified_at of this InlineResponse20016ResponseDisk.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this InlineResponse20016ResponseDisk.


        :param modified_at: The modified_at of this InlineResponse20016ResponseDisk.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    @property
    def percentage_added(self):
        """Gets the percentage_added of this InlineResponse20016ResponseDisk.  # noqa: E501


        :return: The percentage_added of this InlineResponse20016ResponseDisk.  # noqa: E501
        :rtype: int
        """
        return self._percentage_added

    @percentage_added.setter
    def percentage_added(self, percentage_added):
        """Sets the percentage_added of this InlineResponse20016ResponseDisk.


        :param percentage_added: The percentage_added of this InlineResponse20016ResponseDisk.  # noqa: E501
        :type: int
        """

        self._percentage_added = percentage_added

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20016ResponseDisk, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20016ResponseDisk):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20016ResponseDisk):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class UpdateUser(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'email': 'str',
        'firstname': 'str',
        'lastname': 'str',
        'admin': 'bool',
        'role_ids': 'list[int]',
        'current_password': 'str',
        'password': 'str'
    }

    attribute_map = {
        'email': 'email',
        'firstname': 'firstname',
        'lastname': 'lastname',
        'admin': 'admin',
        'role_ids': 'role_ids',
        'current_password': 'current_password',
        'password': 'password'
    }

    def __init__(self, email=None, firstname=None, lastname=None, admin=None, role_ids=None, current_password=None, password=None, _configuration=None):  # noqa: E501
        """UpdateUser - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._email = None
        self._firstname = None
        self._lastname = None
        self._admin = None
        self._role_ids = None
        self._current_password = None
        self._password = None
        self.discriminator = None

        if email is not None:
            self.email = email
        if firstname is not None:
            self.firstname = firstname
        if lastname is not None:
            self.lastname = lastname
        if admin is not None:
            self.admin = admin
        if role_ids is not None:
            self.role_ids = role_ids
        if current_password is not None:
            self.current_password = current_password
        if password is not None:
            self.password = password

    @property
    def email(self):
        """Gets the email of this UpdateUser.  # noqa: E501

        email  # noqa: E501

        :return: The email of this UpdateUser.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this UpdateUser.

        email  # noqa: E501

        :param email: The email of this UpdateUser.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def firstname(self):
        """Gets the firstname of this UpdateUser.  # noqa: E501


        :return: The firstname of this UpdateUser.  # noqa: E501
        :rtype: str
        """
        return self._firstname

    @firstname.setter
    def firstname(self, firstname):
        """Sets the firstname of this UpdateUser.


        :param firstname: The firstname of this UpdateUser.  # noqa: E501
        :type: str
        """

        self._firstname = firstname

    @property
    def lastname(self):
        """Gets the lastname of this UpdateUser.  # noqa: E501


        :return: The lastname of this UpdateUser.  # noqa: E501
        :rtype: str
        """
        return self._lastname

    @lastname.setter
    def lastname(self, lastname):
        """Sets the lastname of this UpdateUser.


        :param lastname: The lastname of this UpdateUser.  # noqa: E501
        :type: str
        """

        self._lastname = lastname

    @property
    def admin(self):
        """Gets the admin of this UpdateUser.  # noqa: E501


        :return: The admin of this UpdateUser.  # noqa: E501
        :rtype: bool
        """
        return self._admin

    @admin.setter
    def admin(self, admin):
        """Sets the admin of this UpdateUser.


        :param admin: The admin of this UpdateUser.  # noqa: E501
        :type: bool
        """

        self._admin = admin

    @property
    def role_ids(self):
        """Gets the role_ids of this UpdateUser.  # noqa: E501


        :return: The role_ids of this UpdateUser.  # noqa: E501
        :rtype: list[int]
        """
        return self._role_ids

    @role_ids.setter
    def role_ids(self, role_ids):
        """Sets the role_ids of this UpdateUser.


        :param role_ids: The role_ids of this UpdateUser.  # noqa: E501
        :type: list[int]
        """

        self._role_ids = role_ids

    @property
    def current_password(self):
        """Gets the current_password of this UpdateUser.  # noqa: E501


        :return: The current_password of this UpdateUser.  # noqa: E501
        :rtype: str
        """
        return self._current_password

    @current_password.setter
    def current_password(self, current_password):
        """Sets the current_password of this UpdateUser.


        :param current_password: The current_password of this UpdateUser.  # noqa: E501
        :type: str
        """

        self._current_password = current_password

    @property
    def password(self):
        """Gets the password of this UpdateUser.  # noqa: E501


        :return: The password of this UpdateUser.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this UpdateUser.


        :param password: The password of this UpdateUser.  # noqa: E501
        :type: str
        """

        self._password = password

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateUser, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateUser):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateUser):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Object Storage REST API

    # Overview  This document outlines the methods available for administrating your VPSA&#174; Object Storage. The API supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or through the X-Access-Key header. Alternately, you can use the username and password parameters for authentication, but we do not recommend this method for anything other than possibly retrieving an API key.  By default , all operations are allowed only to VPSA Object Storage admin. Some actions are allowed by an account admin and they will be marked on the action's header  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some time to complete. When using the API, this can cause some actions, such as adding drives to storage policy, to be undesirably asynchronous. You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Metering API  Metering information can be retrieved using the VPSA Object Storage API for the following components:  - Accounts - Users - Drives - Virtual Controllers - Load Balancer Groups - Storage Policies  Metering information returned by the API is subject to the following constraints:  - 10 seconds interval - 1 hour range - 1 minute interval - 1 day range - 1 hour interval - 30 days range  Values outside the accepted range will be returned as 0.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from Zios.api_client import ApiClient


class VirtualControllersApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def delete_proxy_virtual_controller(self, delete_proxy_virtual_controller, **kwargs):  # noqa: E501
        """delete_proxy_virtual_controller  # noqa: E501

        Remove proxy VCs.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_proxy_virtual_controller(delete_proxy_virtual_controller, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DeleteProxyVirtualController delete_proxy_virtual_controller: (required)
        :return: InlineResponse20055
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_proxy_virtual_controller_with_http_info(delete_proxy_virtual_controller, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_proxy_virtual_controller_with_http_info(delete_proxy_virtual_controller, **kwargs)  # noqa: E501
            return data

    def delete_proxy_virtual_controller_with_http_info(self, delete_proxy_virtual_controller, **kwargs):  # noqa: E501
        """delete_proxy_virtual_controller  # noqa: E501

        Remove proxy VCs.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_proxy_virtual_controller_with_http_info(delete_proxy_virtual_controller, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DeleteProxyVirtualController delete_proxy_virtual_controller: (required)
        :return: InlineResponse20055
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['delete_proxy_virtual_controller']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_proxy_virtual_controller" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'delete_proxy_virtual_controller' is set
        if self.api_client.client_side_validation and ('delete_proxy_virtual_controller' not in params or
                                                       params['delete_proxy_virtual_controller'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `delete_proxy_virtual_controller` when calling `delete_proxy_virtual_controller`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'delete_proxy_virtual_controller' in params:
            body_params = params['delete_proxy_virtual_controller']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/zios/virtual_controllers/remove_proxy_vcs.json', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20055',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_virtual_controllers(self, **kwargs):  # noqa: E501
        """get_all_virtual_controllers  # noqa: E501

        Get a list of Virtual Controllers.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_virtual_controllers(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start: The item number to start from. 0 starts from the beginning.
        :param int limit: The total number of records to return.
        :return: InlineResponse20052
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_virtual_controllers_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_all_virtual_controllers_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_all_virtual_controllers_with_http_info(self, **kwargs):  # noqa: E501
        """get_all_virtual_controllers  # noqa: E501

        Get a list of Virtual Controllers.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_virtual_controllers_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start: The item number to start from. 0 starts from the beginning.
        :param int limit: The total number of records to return.
        :return: InlineResponse20052
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_virtual_controllers" % key
                )
            params[key] = val
        del params['kwargs']

        if self.api_client.client_side_validation and ('start' in params and params['start'] < 0):  # noqa: E501
            raise ValueError("Invalid value for parameter `start` when calling `get_all_virtual_controllers`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start' in params:
            query_params.append(('start', params['start']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/zios/virtual_controllers.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20052',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_cpu_stats(self, id, **kwargs):  # noqa: E501
        """get_cpu_stats  # noqa: E501

        Retrieves metering statistics for the controller for the specified interval.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_cpu_stats(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param int count: Number of points in returned data.
        :param int interval: The interval to collect statistics for, in seconds.
        :return: InlineResponse20056
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_cpu_stats_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_cpu_stats_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_cpu_stats_with_http_info(self, id, **kwargs):  # noqa: E501
        """get_cpu_stats  # noqa: E501

        Retrieves metering statistics for the controller for the specified interval.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_cpu_stats_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param int count: Number of points in returned data.
        :param int interval: The interval to collect statistics for, in seconds.
        :return: InlineResponse20056
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'count', 'interval']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_cpu_stats" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_cpu_stats`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'count' in params:
            query_params.append(('count', params['count']))  # noqa: E501
        if 'interval' in params:
            query_params.append(('interval', params['interval']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/zios/virtual_controllers/{id}/cpu_stats.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20056',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_virtual_controller(self, vc_index, **kwargs):  # noqa: E501
        """get_virtual_controller  # noqa: E501

        Get one Virtual Controller.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_virtual_controller(vc_index, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vc_index: (required)
        :param int start: The item number to start from. 0 starts from the beginning.
        :param int limit: The total number of records to return.
        :return: InlineResponse20053
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_virtual_controller_with_http_info(vc_index, **kwargs)  # noqa: E501
        else:
            (data) = self.get_virtual_controller_with_http_info(vc_index, **kwargs)  # noqa: E501
            return data

    def get_virtual_controller_with_http_info(self, vc_index, **kwargs):  # noqa: E501
        """get_virtual_controller  # noqa: E501

        Get one Virtual Controller.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_virtual_controller_with_http_info(vc_index, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vc_index: (required)
        :param int start: The item number to start from. 0 starts from the beginning.
        :param int limit: The total number of records to return.
        :return: InlineResponse20053
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['vc_index', 'start', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_virtual_controller" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'vc_index' is set
        if self.api_client.client_side_validation and ('vc_index' not in params or
                                                       params['vc_index'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vc_index` when calling `get_virtual_controller`")  # noqa: E501

        if self.api_client.client_side_validation and ('start' in params and params['start'] < 0):  # noqa: E501
            raise ValueError("Invalid value for parameter `start` when calling `get_virtual_controller`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'vc_index' in params:
            path_params['vc_index'] = params['vc_index']  # noqa: E501

        query_params = []
        if 'start' in params:
            query_params.append(('start', params['start']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/zios/virtual_controllers/{vc_index}.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20053',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_virtual_controller_drives(self, vc_index, **kwargs):  # noqa: E501
        """get_virtual_controller_drives  # noqa: E501

        Returns the drives list for a virtual controller.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_virtual_controller_drives(vc_index, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vc_index: (required)
        :return: InlineResponse20054
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_virtual_controller_drives_with_http_info(vc_index, **kwargs)  # noqa: E501
        else:
            (data) = self.get_virtual_controller_drives_with_http_info(vc_index, **kwargs)  # noqa: E501
            return data

    def get_virtual_controller_drives_with_http_info(self, vc_index, **kwargs):  # noqa: E501
        """get_virtual_controller_drives  # noqa: E501

        Returns the drives list for a virtual controller.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_virtual_controller_drives_with_http_info(vc_index, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vc_index: (required)
        :return: InlineResponse20054
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['vc_index']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_virtual_controller_drives" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'vc_index' is set
        if self.api_client.client_side_validation and ('vc_index' not in params or
                                                       params['vc_index'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vc_index` when calling `get_virtual_controller_drives`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'vc_index' in params:
            path_params['vc_index'] = params['vc_index']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/zios/virtual_controllers/{vc_index}/drives.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20054',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def show_bandwidth_throughput_metering_on_vc(self, id, **kwargs):  # noqa: E501
        """show_bandwidth_throughput_metering_on_vc  # noqa: E501

        Shows bandwidth throughput metering (B/s) on a VC.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.show_bandwidth_throughput_metering_on_vc(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str service:
        :param int interval:
        :param int count:
        :return: InlineResponse20014
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.show_bandwidth_throughput_metering_on_vc_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.show_bandwidth_throughput_metering_on_vc_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def show_bandwidth_throughput_metering_on_vc_with_http_info(self, id, **kwargs):  # noqa: E501
        """show_bandwidth_throughput_metering_on_vc  # noqa: E501

        Shows bandwidth throughput metering (B/s) on a VC.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.show_bandwidth_throughput_metering_on_vc_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str service:
        :param int interval:
        :param int count:
        :return: InlineResponse20014
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'service', 'interval', 'count']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method show_bandwidth_throughput_metering_on_vc" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `show_bandwidth_throughput_metering_on_vc`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'service' in params:
            query_params.append(('service', params['service']))  # noqa: E501
        if 'interval' in params:
            query_params.append(('interval', params['interval']))  # noqa: E501
        if 'count' in params:
            query_params.append(('count', params['count']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/zios/virtual_controllers/{id}/throughput.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20014',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def show_iops_metring_of_vc(self, id, **kwargs):  # noqa: E501
        """show_iops_metring_of_vc  # noqa: E501

        Shows IOPs metering on a VC.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.show_iops_metring_of_vc(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str service:
        :param int interval:
        :param int count:
        :return: InlineResponse20012
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.show_iops_metring_of_vc_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.show_iops_metring_of_vc_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def show_iops_metring_of_vc_with_http_info(self, id, **kwargs):  # noqa: E501
        """show_iops_metring_of_vc  # noqa: E501

        Shows IOPs metering on a VC.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.show_iops_metring_of_vc_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str service:
        :param int interval:
        :param int count:
        :return: InlineResponse20012
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'service', 'interval', 'count']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method show_iops_metring_of_vc" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `show_iops_metring_of_vc`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'service' in params:
            query_params.append(('service', params['service']))  # noqa: E501
        if 'interval' in params:
            query_params.append(('interval', params['interval']))  # noqa: E501
        if 'count' in params:
            query_params.append(('count', params['count']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/zios/virtual_controllers/{id}/iops.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20012',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def show_latency_metering_on_vc(self, id, **kwargs):  # noqa: E501
        """show_latency_metering_on_vc  # noqa: E501

        Shows latency metering (ms) on a VC.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.show_latency_metering_on_vc(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str service:
        :param int interval:
        :param int count:
        :return: InlineResponse20013
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.show_latency_metering_on_vc_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.show_latency_metering_on_vc_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def show_latency_metering_on_vc_with_http_info(self, id, **kwargs):  # noqa: E501
        """show_latency_metering_on_vc  # noqa: E501

        Shows latency metering (ms) on a VC.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.show_latency_metering_on_vc_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str service:
        :param int interval:
        :param int count:
        :return: InlineResponse20013
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'service', 'interval', 'count']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method show_latency_metering_on_vc" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `show_latency_metering_on_vc`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'service' in params:
            query_params.append(('service', params['service']))  # noqa: E501
        if 'interval' in params:
            query_params.append(('interval', params['interval']))  # noqa: E501
        if 'count' in params:
            query_params.append(('count', params['count']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/zios/virtual_controllers/{id}/latency.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20013',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
